from enum import Enum


class PredefinedServiceName(Enum):
    AOL = "AOL"
    AP_DEFENDER = "AP-Defender"
    AT_DEFENDER = "AT-Defender"
    BGP = "BGP"
    CITRIX_ICA = "Citrix_ICA"
    CP_EXNET_PK = "CP_Exnet_PK"
    CP_EXNET_RESOLVE = "CP_Exnet_resolve"
    CP_REDUNDANT = "CP_redundant"
    CP_REPORTING = "CP_reporting"
    CP_RTM = "CP_rtm"
    CP_SEAM = "CP_seam"
    CP_SMARTPORTAL = "CP_SmartPortal"
    CP_SSL_NETWORK_EXTENDER = "CP_SSL_Network_Extender"
    CPD = "CPD"
    CPD_AMON = "CPD_amon"
    CPMI = "CPMI"
    DAYTIME_TCP = "daytime-tcp"
    DISCARD_TCP = "discard-tcp"
    DOMAIN_TCP = "domain-tcp"
    ECHO_TCP = "echo-tcp"
    EDGE = "EDGE"
    ENTRUST_ADMIN = "Entrust-Admin"
    ENTRUST_KEYMGMT = "Entrust-KeyMgmt"
    EPMAP_TCP = "epmap-tcp"
    EXEC = "exec"
    FIBMGR = "FIBMGR"
    FINGER = "finger"
    FTP = "ftp"
    FW1 = "FW1"
    FW1_AMON = "FW1_amon"
    FW1_CLNTAUTH_HTTP = "FW1_clntauth_http"
    FW1_CLNTAUTH_TELNET = "FW1_clntauth_telnet"
    FW1_CPRID = "FW1_CPRID"
    FW1_CVP = "FW1_cvp"
    FW1_ELA = "FW1_ela"
    FW1_ICA_MGMT_TOOLS = "FW1_ica_mgmt_tools"
    FW1_ICA_PULL = "FW1_ica_pull"
    FW1_ICA_PUSH = "FW1_ica_push"
    FW1_ICA_SERVICES = "FW1_ica_services"
    FW1_KEY = "FW1_key"
    FW1_LEA = "FW1_lea"
    FW1_LOG = "FW1_log"
    FW1_MGMT = "FW1_mgmt"
    FW1_NETSO = "FW1_netso"
    FW1_OMI = "FW1_omi"
    FW1_OMI_SIC = "FW1_omi-sic"
    FW1_PSLOGON = "FW1_pslogon"
    FW1_PSLOGON_NG = "FW1_pslogon_NG"
    FW1_SAM = "FW1_sam"
    FW1_SDS_LOGON = "FW1_sds_logon"
    FW1_SDS_LOGON_NG = "FW1_sds_logon_NG"
    FW1_SNAUTH = "FW1_snauth"
    FW1_TOPO = "FW1_topo"
    FW1_UAA = "FW1_uaa"
    FW1_UFP = "FW1_ufp"
    GOPHER = "gopher"
    GOTOMYPC = "GoToMyPC"
    H323 = "H323"
    HTTP = "http"
    HTTP_AND_HTTPS_PROXY = "HTTP_and_HTTPS_proxy"
    HTTPS = "https"
    IDENT = "ident"
    IKE_TCP = "IKE-tcp"
    IMAP = "imap"
    IMAP_SSL = "IMAP-SSL"
    IPSO_CLUSTERING_MGMT_PROTOCOL = "IPSO_Clustering_Mgmt_Protocol"
    IRC2 = "irc2"
    KERBEROS_V5_TCP = "Kerberos_v5_TCP"
    LDAP = "ldap"
    LDAP_SSL = "ldap-ssl"
    LOGIN = "login"
    LOTUS = "lotus"
    LPDW0RM = "lpdw0rm"
    MICROSOFT_DS = "microsoft-ds"
    MS_SQL_MONITOR = "MS-SQL-Monitor"
    MS_SQL_SERVER = "MS-SQL-Server"
    MSNP = "MSNP"
    MYSQL = "MySQL"
    NBSESSION = "nbsession"
    NCP = "NCP"
    NETSHOW = "netshow"
    NETSTAT = "netstat"
    NFSD_TCP = "nfsd-tcp"
    NNTP = "nntp"
    NTP_TCP = "ntp-tcp"
    OAS_NAMESERVER = "OAS-NameServer"
    OAS_ORB = "OAS-ORB"
    PCANYWHERE_DATA = "pcANYWHERE-data"
    PCTELECOMMUTE_FILESYNC = "pcTELECOMMUTE-FileSync"
    POP_2 = "pop-2"
    POP_3 = "pop-3"
    POP3S = "POP3S"
    POSTGRESQL = "PostgreSQL"
    PPTP_TCP = "pptp-tcp"
    RAINWALL_COMMAND = "RainWall_Command"
    REAL_AUDIO = "Real-Audio"
    REALSECURE = "RealSecure"
    REMOTE_DEBUG = "Remote_Debug"
    REMOTE_DESKTOP_PROTOCOL = "Remote_Desktop_Protocol"
    RTSP = "rtsp"
    SCCP = "SCCP"
    SECURIDPROP = "securidprop"
    SHELL = "shell"
    SIP_TLS = "sip_tls"
    SIP_TCP = "sip-tcp"
    SMTP = "smtp"
    SMTPS = "SMTPS"
    SQLNET1_2 = "sqlnet1-2"
    SQLNET2_1525 = "sqlnet2-1525"
    SQLNET2_1526 = "sqlnet2-1526"
    SQUID_NTLM = "Squid_NTLM"
    SSH = "ssh"
    STONEBEAT_CONTROL = "StoneBeat-Control"
    STONEBEAT_DAEMON = "StoneBeat-Daemon"
    T_120 = "T.120"
    TACACSPLUS = "TACACSplus"
    TCP_HIGH_PORTS = "tcp-high-ports"
    TELNET = "telnet"
    TIME_TCP = "time-tcp"
    USERCHECK = "UserCheck"
    UUCP = "uucp"
    WAIS = "wais"
    X11 = "X11"
    YAHOO_MESSENGER_MESSAGES = "Yahoo_Messenger_messages"
    YAHOO_MESSENGER_VOICE_CHAT_TCP = "Yahoo_Messenger_Voice_Chat_TCP"
    YAHOO_MESSENGER_WEBCAMS = "Yahoo_Messenger_Webcams"
    BIFF = "biff"
    BOOTP = "bootp"
    CITRIX_ICA_BROWSING = "Citrix_ICA_Browsing"
    DAYTIME_UDP = "daytime-udp"
    DHCP = "dhcp"
    DISCARD_UDP = "discard-udp"
    DOMAIN_UDP = "domain-udp"
    E2ECP = "E2ECP"
    ECHO_UDP = "echo-udp"
    EPMAP_UDP = "epmap-udp"
    FW1_LOAD_AGENT = "FW1_load_agent"
    FW1_SCV_KEEP_ALIVE = "FW1_scv_keep_alive"
    FW1_SNMP = "FW1_snmp"
    H323_RAS = "H323_ras"
    HOTLINE_TRACKER = "Hotline_tracker"
    ICQ_LOCATOR = "ICQ_locator"
    IKE = "IKE"
    IKE_NAT_TRAVERSAL = "IKE_NAT_TRAVERSAL"
    KERBEROS_V5_UDP = "Kerberos_v5_UDP"
    KERBEROS_UDP = "kerberos-udp"
    L2TP = "L2TP"
    LDAP_UDP = "ldap-udp"
    METAIP_UAT = "MetaIP-UAT"
    MGCP_CA = "mgcp_CA"
    MGCP_MG = "mgcp_MG"
    MICROSOFT_DS_UDP = "microsoft-ds-udp"
    MS_SQL_MONITOR_UDP = "MS-SQL-Monitor_UDP"
    MS_SQL_SERVER_UDP = "MS-SQL-Server_UDP"
    MSN_MESSENGER_1863_UDP = "MSN_Messenger_1863_UDP"
    MSN_MESSENGER_5190 = "MSN_Messenger_5190"
    MSN_MESSENGER_VOICE = "MSN_Messenger_Voice"
    NAME = "name"
    NBDATAGRAM = "nbdatagram"
    NBNAME = "nbname"
    NEW_RADIUS_ACCOUNTING = "NEW-RADIUS-ACCOUNTING"
    NFSD = "nfsd"
    NTP_UDP = "ntp-udp"
    PCANYWHERE_STAT = "pcANYWHERE-stat"
    RADIUS = "RADIUS"
    RADIUS_ACCOUNTING = "RADIUS-ACCOUNTING"
    RAINWALL_DAEMON = "RainWall_Daemon"
    RAINWALL_STATUS = "RainWall_Status"
    RAINWALL_STOP = "RainWall_Stop"
    RDP = "RDP"
    RIP = "rip"
    RIPNG = "RIPng"
    SECURID_UDP = "securid-udp"
    SIP = "sip"
    SNMP = "snmp"
    SWTP_GATEWAY = "SWTP_Gateway"
    SWTP_SMS = "SWTP_SMS"
    SYSLOG = "syslog"
    TACACS = "TACACS"
    TFTP = "tftp"
    TIME_UDP = "time-udp"
    TUNNEL_TEST = "tunnel_test"
    UDP_HIGH_PORTS = "udp-high-ports"
    VPN1_IPSEC_ENCAPSULATION = "VPN1_IPSEC_encapsulation"
    WAP_WDP = "wap_wdp"
    WAP_WDP_ENC = "wap_wdp_enc"
    WAP_WTP = "wap_wtp"
    WAP_WTP_ENC = "wap_wtp_enc"
    WHO = "who"
    DEST_UNREACH = "dest-unreach"
    ECHO_REPLY = "echo-reply"
    ECHO_REQUEST = "echo-request"
    INFO_REPLY = "info-reply"
    INFO_REQ = "info-req"
    MASK_REPLY = "mask-reply"
    MASK_REQUEST = "mask-request"
    PARAM_PRBLM = "param-prblm"
    REDIRECT = "redirect"
    SOURCE_QUENCH = "source-quench"
    TIME_EXCEEDED = "time-exceeded"
    TIMESTAMP = "timestamp"
    TIMESTAMP_REPLY = "timestamp-reply"
    AH = "AH"
    EGP = "egp"
    ESP = "ESP"
    FW1_ENCAPSULATION = "FW1_Encapsulation"
    GGP = "ggp"
    GRE = "gre"
    ICMP_PROTO = "icmp-proto"
    IGMP = "igmp"
    IGRP = "igrp"
    IP_MOBILITY = "IP_Mobility"
    OSPF = "ospf"
    PIM = "PIM"
    SIT = "SIT"
    SITARA = "Sitara"
    SKIP = "SKIP"
    SUN_ND = "SUN_ND"
    SWIPE = "SWIPE"
    VRRP = "vrrp"
    OTHER = "other"


class ApplicationIdentityName(Enum):
    _BAO = "100bao"
    _C_ENTERPRISE = "1c-enterprise"
    _UND1_MAIL = "1und1-mail"
    _CH = "2ch"
    _CH_POSTING = "2ch-posting"
    __SAFEGUARD_UPDATE = "360 Safeguard-update"
    _SHARED = "4shared"
    _SYNC = "4sync"
    __COM = "51.com"
    __COM_BASE = "51.com-base"
    __COM_BBS = "51.com-bbs"
    __COM_GAMES = "51.com-games"
    __COM_MAIL = "51.com-mail"
    __COM_MUSIC = "51.com-music"
    __COM_POSTING = "51.com-posting"
    __COM_WEBDISK = "51.com-webdisk"
    ABSOLUTE_MANAGE = "Absolute Manage"
    ACCESS_GRID = "Access-Grid"
    ACRONIS_SNAP_DEPLOY = "Acronis Snap Deploy"
    ACTIVE_DIRECTORY = "Active Directory"
    ACTIVENET = "Activenet"
    ACTIVESYNC_PROTOCOL = "ActiveSync Protocol"
    ADSELFSERVICE = "ADSelfService"
    ADNSTREAM = "ADNstream"
    ADOBE_CONNECT = "Adobe Connect"
    ADOBE_CONNECT_MEETING = "Adobe Connect-meeting"
    ADOBE_CONNECT_MEETING_FILE_TRANSFER = "Adobe Connect-meeting-file transfer"
    ADOBE_CONNECT_MEETING_REMOTE_CONTROL = "Adobe-Connect-meeting-remote-control"
    ADOBE_CONNECTNOW = "Adobe Connectnow"
    ADOBE_CONNECTNOW_BASE = "Adobe Connectnow-base"
    ADOBE_CONNECTNOW_FILE_TRANSFER = "Adobe Connectnow File Transfer"
    ADOBE_CONNECTNOW_REMOTE_CONTROL = "Adobe Connectnow Remote Control"
    ADOBE_CQ = "Adobe CQ"
    ADOBE_CREATIVE_CLOUD = "Adobe Creative Cloud"
    ADOBE_FLASH_SOCKETPOLICY_SERVER = "Adobe Flash Socketpolicy Server"
    ADOBE_MEDIA_PLAYER = "Adobe Media Player"
    ADOBE_ONLINE_OFFICE = "Adobe Online Office"
    ADOBE_UPDATE = "Adobe Update"
    ADRIVE = "ADrive"
    AFARIA = "Afaria"
    AFP = "Afp"
    AFREECA = "Afreeca"
    AFS = "AFS"
    AIM = "AIM"
    AIM_AUDIO = "AIM-audio"
    AIM_BASE = "AIM-base"
    AIM_FILE_TRANSFER = "AIM-file transfer"
    AIM_VIDEO = "AIM-video"
    AIM_EXPRESS = "AIM Express"
    AIM_EXPRESS_BASE = "AIM Express-base"
    AIM_EXPRESS_FILE_TRANSFER = "AIM Express-file transfer"
    AIM_MAIL = "Aim Mail"
    AIR_VIDEO = "air-video"
    AIRAIM = "AirAIM"
    AIRDROID = "AirDroid"
    AIRTIME = "Airtime"
    AKAMAI_CLIENT = "Akamai Client"
    ALIWANGWANG = "AliWangWang"
    ALIWANGWANG_AUDIO_VIDEO = "AliWangWang-audio-video"
    ALI_WANGWANG_BASE = "Ali-WangWang-base"
    ALIWANGWANG_FILE_TRANSFER = "AliWangWang-file-transfer"
    ALIWANGWANG_REMOTE_CONTROL = "AliWangWang-remote-control"
    ALISOFT = "Alisoft"
    ALL_SLOTS_ONLINE_CASINO = "All Slots Online Casino"
    ALLPEERS = "AllPeers"
    ALPEMIX = "Alpemix"
    ALTIRIS = "Altiris"
    AMAZON_WEB_SERVICES = "Amazon Web Services"
    AMAZON_CLOUD_DRIVE = "Amazon Cloud Drive"
    AMAZON_CLOUD_DRIVE_BASE = "Amazon Cloud Drive-base"
    AMAZON_CLOUD_DRIVE_UPLOAD = "Amazon Cloud Drive-upload"
    AMAZON_CLOUD_PLAYER = "Amazon Cloud Player"
    AMAZON_INSTANT_VIDEO = "Amazon Instant Video"
    AMAZON_UNBOX = "Amazon Unbox"
    AMEBA_BLOG_POSTING = "Ameba-blog-posting"
    AMEBA_NOW = "Ameba-now"
    AMEBA_NOW_BASE = "Ameba-now-base"
    AMEBA_NOW_POSTING = "Ameba-now-posting"
    AMMYY_ADMIN = "Ammyy Admin"
    AMQP = "Amqp"
    ANDROID_MARKET = "Android-market"
    ANTS_P2P = "Ants P2P"
    AOL_MESSAGE_BOARD = "AOL Message Board"
    AOL_PROXY = "AOL Proxy"
    APACHE_JSERV = "Apache-jserv"
    APACHE_ZOOKEEPER = "Apache ZooKeeper"
    POWERCHUTE = "PowerChute"
    APPLE_AIRPLAY = "Apple AirPlay"
    APPLE_AIRPORT = "Apple Airport"
    APPLE_APP_STORE = "Apple App Store"
    APPLE_GAME_CENTER = "Apple Game Center"
    APPLE_LOCATION_SERVICE = "Apple Location Service"
    APPLE_MAPS = "Apple Maps"
    APPLE_PUSH_NOTIFICATION_SERVICE = "Apple Push Notification Service"
    APPLE_REMOTE_DESKTOP = "Apple Remote Desktop"
    APPLE_SOFTWARE_UPDATE = "Apple Software Update"
    APPLEJUICE = "Applejuice"
    APT_GET = "Apt-get"
    ARCGIS = "ArcGIS"
    ARCSERVE = "ARCserve"
    ARES = "Ares"
    ARIEL = "Ariel"
    ARUBA_PAPI = "Aruba PAPI"
    AS2 = "AS2"
    ASANA = "Asana"
    ASF_STREAMING = "ASF Streaming"
    ASPROXY = "ASProxy"
    ASTERISK_IAX = "Asterisk-iax"
    ASUS_WEBSTORAGE = "Asus Webstorage"
    ATEMPO_TINA = "Atempo Tina"
    ATOM_PROTOCOL = "Atom Protocol"
    AT_T_CONNECT = "AT&T Connect"
    AT_T_LOCKER = "AT&T Locker"
    AUTOBAHN = "Autobahn"
    AVAMAR = "Avamar"
    AVAST_ANTIVIRUS_UPDATE = "Avast Antivirus-update"
    AVAYA_PHONE_PING = "Avaya Phone Ping"
    AVAYA_WEBALIVE = "Avaya-webalive"
    AVAYA_WEBALIVE_BASE = "Avaya-webalive-base"
    AVAYA_WEBALIVE_DESKTOP_SHARING = "Avaya-webalive-desktop-sharing"
    AVAYA_WEBALIVE_FILE_TRANSFER = "Avaya-webalive-file-transfer"
    AVAYA_WEBALIVE_VOICE = "Avaya-webalive-voice"
    AVG_UPDATE = "AVG-Update"
    AVIRA_ANTIVIR_UPDATE = "Avira Antivir-update"
    AVOCENT = "Avocent"
    AVOIDR = "Avoidr"
    AXIFILE = "AxiFile"
    AZUREUS = "Azureus"
    BABELGUM = "Babelgum"
    BABYLON = "Babylon"
    BACKPACK_EDITING = "BackPack-editing"
    BACKUP_EXEC = "Backup Exec"
    BACKWEB = "BackWeb"
    BACNET_PROTOCOL = "BACNet Protocol"
    BACULA = "Bacula"
    BADONGO = "Badongo"
    BADOO = "Badoo"
    BAIDU_HI = "Baidu Hi"
    BAIDU_HI_AUDIO_VIDEO = "Baidu Hi-audio-video"
    BAIDU_HI_GAMES = "Baidu Hi-games"
    BAIDU_HI_FILE_TRANSFER = "Baidu Hi-file transfer"
    BAIDU_HI_BASE = "Baidu Hi-Base"
    BAIDU_IME = "Baidu IME"
    BAIDU_WEBMESSENGER = "Baidu Webmessenger"
    BAOFENG = "Baofeng"
    BARRACUDA_BACKUP = "Barracuda Backup"
    BATCHBOOK = "Batchbook"
    BATTLE_NET = "Battle.Net"
    BATTLEFIELD_2 = "Battlefield 2"
    BBC_IPLAYER = "BBC iPlayer"
    BBCP = "BBCP"
    BEAMYOURSCREEN = "BeamYourScreen"
    BEBO = "Bebo"
    BEBO_BASE = "Bebo-base"
    BEBO_MAIL = "Bebo-mail"
    BEBO_POSTING = "Bebo-posting"
    BEINSYNC = "BeInSync"
    BET365 = "bet365"
    BFCP = "BFCP"
    BFD_PROTOCOL = "BFD Protocol"
    BGP_PROTOCOL = "BGP Protocol"
    BIG_BROTHER = "Big Brother"
    BIGUPLOAD = "bigupload"
    BIT9_SECURITY_PLATFORM = "Bit9 Security Platform"
    BITBUCKET = "Bitbucket"
    BITCASA = "Bitcasa"
    BITCOIN = "Bitcoin"
    BITDEFENDER = "Bitdefender"
    BITTORRENT_PROTOCOL = "BitTorrent Protocol"
    BITTORRENT_SYNC = "BitTorrent Sync"
    BLACKBERRY = "BlackBerry"
    BLACKBOARD = "Blackboard"
    BLIN = "Blin"
    BLOG_POSTING = "Blog-posting"
    BLOGGER_BLOG_POSTING = "Blogger-blog posting"
    BLOOMBERG_PROFESSIONAL = "Bloomberg professional"
    BLOKUS = "Blokus"
    BLUE_COAT_ADN = "Blue Coat ADN"
    BLUE_COAT_AUTH_AGENT = "Blue Coat Auth Agent"
    BLUEJEANS = "BlueJeans"
    BOMBERCLONE = "BomberClone"
    BOMGAR = "Bomgar"
    BONPOO = "bonpoo"
    BOSCH_RCP_PLUS = "Bosch RCP Plus"
    BOXNET = "Boxnet"
    BOXNET_UPLOADING = "Boxnet-uploading"
    BOXNET_EDITING = "Boxnet-editing"
    BOXNET_BASE = "Boxnet-base"
    BRIGHTCLOUD = "BrightCloud"
    BRIGHTCOVE = "BrightCove"
    BRIGHTTALK = "Brighttalk"
    BUBBLY = "Bubbly"
    BUDDYBUDDY = "Buddybuddy"
    BUDDYBUDDY_BASE = "Buddybuddy-base"
    BUDDYBUDDY_FILE_TRANSFER = "Buddybuddy-file-transfer"
    BUGZILLA = "Bugzilla"
    BYPASS = "Bypass"
    BYPASSTHAT = "BypassThat"
    CA_MQ_SERVICE = "CA MQ Service"
    CA_NIMSOFT_MONITOR = "CA Nimsoft Monitor"
    CA_SDM = "CA SDM"
    CAIHONG = "Caihong"
    CALAMEO = "Calameo"
    CALL_OF_DUTY = "Call of Duty"
    CALLPILOT = "CallPilot"
    CAMFROG = "Camfrog"
    CAMO_PROXY = "Camo Proxy"
    CAMOS = "Camos"
    CAMPFIRE = "Campfire"
    CANON_BJNP = "Canon BJNP"
    CAPWAP = "CAPWAP"
    CARBONITE = "Carbonite"
    CAREFX = "Carefx"
    CASSANDRA = "Cassandra"
    CBS_VIDEO = "CBS-video"
    CDDB_PROTOCOL = "CDDB Protocol"
    CENTRIC_CRM = "Centric CRM"
    CENTURION = "Centurion"
    CERTEON_ACELERA = "Certeon aCelera"
    CGI_IRC = "CGI:IRC"
    CGI_PROXY = "CGI-Proxy"
    CHANNEL4 = "Channel4"
    CHARGEN_PROTOCOL = "CHARGEN Protocol"
    CHATANGO = "Chatango"
    CHATROULETTE = "Chatroulette"
    CHECK_POINT_CLIENT_AUTHENTICATION = "Check Point Client Authentication"
    CHECK_POINT_CPD = "Check Point CPD"
    CHECK_POINT_CPMI = "Check Point CPMI"
    CHECK_POINT_LOGGING = "Check Point logging"
    CHECK_POINT_RDP_PROTOCOL = "Check Point RDP Protocol"
    CHECKPIONT_ENDPOINT_SECURITY_VPN = "Checkpiont Endpoint Security VPN"
    CHIKKA_MESSENGER = "Chikka-messenger"
    CHINAREN = "Chinaren"
    CHINAREN_CHAT = "Chinaren-chat"
    CHINAREN_APPS = "Chinaren-apps"
    CHINAREN_MAIL = "Chinaren-mail"
    CHINAREN_POSTING = "Chinaren-posting"
    CHINAREN_BASE = "Chinaren-base"
    CHROME_REMOTE_DESKTOP = "Chrome Remote Desktop"
    CINEMAGRAM = "Cinemagram"
    CIP_ETHERNET_IP = "CIP-Ethernet IP"
    CIRCUMVENTOR = "Circumventor"
    CISCO_DRP = "Cisco DRP"
    CISCO_NAC = "Cisco NAC"
    CISCO_RTMT = "Cisco RTMT"
    CISCO_WLC_MOBILITY = "Cisco WLC-mobility"
    CISCO_WLC_RRM = "Cisco WLC-rrm"
    CISCO_VPN = "Cisco VPN"
    CITRIX = "Citrix"
    CITRIX_JEDI_PROTOCOL = "Citrix JEDI Protocol"
    CITRIX_LICENSE_SERVER = "Citrix License Server"
    CLARIZEN = "Clarizen"
    CLASSMATES = "Classmates"
    CLEARSPACE = "Clearspace"
    CLICKVIEW = "ClickView"
    CLIP2NET = "Clip2Net"
    CLOUDMARK_DESKTOP = "Cloudmark Desktop"
    CLOUDON = "CloudOn"
    CLUB_COOEE = "Club Cooee"
    COLLECTD = "Collectd"
    COMCAST_WEBMAIL = "Comcast WebMail"
    COMMVAULT = "Commvault"
    COMPASS = "Compass"
    COMPUTRACE = "Computrace"
    CONCUR = "Concur"
    CONDOR = "Condor"
    CONFLUENCE = "Confluence"
    CONSTANT_CONTACT = "Constant Contact"
    CONVOQ = "Convoq"
    COOLTALK = "CoolTalk"
    CORALCDN_USER = "Coralcdn-user"
    CORBA = "Corba"
    COTP = "COTP"
    COX_WEBMAIL = "Cox WebMail"
    CPQ_WBEM = "CPQ-Wbem"
    CRASHPLAN = "Crashplan"
    CROSSLOOP = "CrossLoop"
    CUBBY = "Cubby"
    CUBRID = "Cubrid"
    CUPS = "CUPS"
    CVS = "CVS"
    CVSUP = "CVSup"
    CYBER_ARK_VAULT = "Cyber-Ark Vault"
    CYBERGHOST_VPN = "CyberGhost VPN"
    CYGNET_SCADA = "CygNet SCADA"
    CYWORLD = "Cyworld"
    DAAP = "DAAP"
    DABBLE_DB = "Dabble DB"
    DAILYMOTION = "DailyMotion"
    DAMEWARE_MINI_REMOTE_PROTOCOL = "Dameware-mini remote Protocol"
    DATA_BIN = "Data-bin"
    DAUM = "Daum"
    DAUM_MAIL = "Daum-mail"
    DAUM_CAFE_POSTING = "Daum-cafe-posting"
    DAUM_BLOG_POSTING = "Daum-blog posting"
    DAUM_CLOUD = "Daum-cloud"
    DAUM_MYPEOPLE = "Daum mypeople"
    DAUM_TOUCH = "Daum Touch"
    DAYTIME_PROTOCOL = "Daytime Protocol"
    DAZHIHUI = "Dazhihui"
    DB2 = "DB2"
    DC_UNIVERSE_ONLINE = "DC Universe Online"
    DCC_ANTI_SPAM = "DCC Anti-Spam"
    DCINSIDE = "Dcinside"
    DCINSIDE_POSTING = "Dcinside-posting"
    DCINSIDE_BASE = "Dcinside-base"
    DCLINK = "dcLINK"
    DEALIO_TOOLBAR = "Dealio Toolbar"
    DEEZER = "Deezer"
    DELL_DRAC = "Dell-DRAC"
    DELL_UPDATE = "Dell update"
    DELL_WYSE_DEVICE_MANAGER = "Dell Wyse Device Manager"
    DEPOSIT_FILES = "Deposit Files"
    DESKMETRICS = "DeskMetrics"
    DESKNETS = "Desknets"
    DESKSHARE = "Deskshare"
    DESKTOPTWO = "Desktoptwo"
    DHCP_PROTOCOL = "DHCP Protocol"
    DHCPV6 = "DHCPv6"
    DHL_EASYLOG = "DHL-easylog"
    DIAMETER = "Diameter"
    DICOM = "DICOM"
    DIGG_POSTING = "Digg-posting"
    DIINO = "Diino"
    DIMDIM = "Dimdim"
    DIODEO = "Diodeo"
    DIRECT_CONNECT = "Direct Connect"
    DISCARD = "Discard"
    DISQUS = "Disqus"
    DISTCC = "distcc"
    DIVSHARE = "DivShare"
    DL_FREE = "DL Free"
    DNP3_PROTOCOL = "DNP3 Protocol"
    DNS_PROTOCOL = "DNS Protocol"
    DNSCRYPT = "DNSCrypt"
    DOCSTOC = "Docstoc"
    DOCSTOC_BASE = "Docstoc-base"
    DOCSTOC_UPLOADING = "Docstoc-uploading"
    DOCUWARE = "Docuware"
    DONTCENSORME = "Dontcensorme"
    DOCUSIGN = "DocuSign"
    DOOF = "Doof"
    DOSHOW = "Doshow"
    DOSTUPEST = "Dostupest"
    DOTMAC = "dotmac"
    DRAUGIEM = "Draugiem"
    DRDA = "DRDA"
    DRIVEHQ = "DriveHQ"
    DROP_IO = "drop.io"
    DROPBOKS = "DropBoks"
    DROPBOX = "Dropbox"
    DROPLR = "Droplr"
    DSR = "DSR"
    DTLS_PROTOCOL = "DTLS Protocol"
    DROPSEND = "DropSend"
    DYNAMICINTRANET = "DynamicIntranet"
    EA_FIFA = "EA Fifa"
    EARTHCAM = "Earthcam"
    EASY_SHARE = "Easy-Share"
    EATLIME = "EatLime"
    EBAY_DESKTOP = "Ebay Desktop"
    EBUDDY = "eBuddy"
    ECHO = "Echo"
    ECHOWARE = "Echoware"
    EDITGRID = "EditGrid"
    EFRIEND = "eFriend"
    EGLOOS_BLOG_POSTING = "Egloos-blog-posting"
    EGP_PROTOCOL = "EGP Protocol"
    EIGRP = "EIGRP"
    EIQ_SECURITY_ANALYZER = "EIQ Security Analyzer"
    EGNYTE = "Egnyte"
    EKLOGIN = "Eklogin"
    ELASTICSEARCH = "Elasticsearch"
    ELCOM_90 = "ELCOM-90"
    ELECTRIC_COMMANDER = "Electric Commander"
    EMC_DATA_DOMAIN = "EMC-data-domain"
    EMC_DOCUMENTUM_WEBTOP = "EMC-documentum-webtop"
    EMC_NETWORKER = "EMC-networker"
    EMC_RECOVERPOINT = "EMC-recoverpoint"
    EMCON = "Emcon"
    EMC_SMARTPACKETS = "EMC-smartpackets"
    ELLUMINATE = "Elluminate"
    EMULE = "eMule"
    ENDNOTE = "EndNote"
    EPEACHTREE = "ePeachtree"
    EROOM_HOST = "Eroom-host"
    EROOM_NET = "Eroom-net"
    ESET_REMOTE_ADMIN = "ESET Remote Admin"
    ESET_UPDATE = "ESET Update"
    ESIGNAL = "eSignal"
    ESNIPS = "eSnips"
    EVAULT = "EVault"
    EVE_ONLINE = "EVE Online"
    EVERNOTE = "Evernote"
    EVONY = "Evony"
    EYEJOT = "Eyejot"
    EZHELP = "ezHelp"
    EZPEER = "ezPeer"
    FACEBOOK = "Facebook"
    FACEBOOK_APPS = "Facebook Apps"
    FACEBOOK_BASE = "Facebook-base"
    FACEBOOK_CHAT = "Facebook-chat"
    FACEBOOK_FILE_SHARING = "Facebook-file sharing"
    FACEBOOK_MAIL = "Facebook-mail"
    FACEBOOK_POSTING = "Facebook-posting"
    FACEBOOK_SOCIAL_PLUGIN = "Facebook-social-plugin"
    FACETIME = "Facetime"
    FASTMAIL = "Fastmail"
    FASTVIEWER = "FastViewer"
    FC2_BLOG_POSTING = "FC2-blog-posting"
    FETION = "Fetion"
    FETION_AUDIO_VIDEO = "Fetion-audio-video"
    FETION_FILE_TRANSFER = "Fetion-file-transfer"
    FETION_BASE = "Fetion-base"
    FILEAPP = "FileApp"
    FILECATALYST_DIRECT = "FileCatalyst Direct"
    FILEDROPPER = "FileDropper"
    FILEGURI = "Fileguri"
    FILEMAIL = "Filemail"
    FILEMAKER_ANOUNCEMENT = "Filemaker Anouncement"
    FILEMAKER_PRO = "FileMaker Pro"
    FILER_CX = "Filer.cx"
    FILES_TO = "Files.to"
    FILESANYWHERE = "FilesAnywhere"
    FILESERVE = "FileServe"
    FILESONIC = "FileSonic"
    FILESTUBE = "Filestube"
    FIREFOX_UPDATE = "Firefox-update"
    FIREPHOENIX = "FirePhoenix"
    FIRSTCLASS = "FirstClass"
    FLASHGET = "FlashGet"
    FLICKR = "Flickr"
    FLICKR_UPLOADING = "Flickr-uploading"
    FLICKR_BASE = "Flickr-base"
    FLIXSTER = "Flixster"
    FLIXWAGON = "Flixwagon"
    FLIXWAGON_POSTING = "Flixwagon-posting"
    FLIXWAGON_SHARING = "Flixwagon-sharing"
    FLIXWAGON_BROADCAST = "Flixwagon-broadcast"
    FLIXWAGON_DOWNLOAD = "Flixwagon-download"
    FLIXWAGON_BASE = "Flixwagon-base"
    FLUMOTION = "Flumotion"
    FLUXIOM = "Fluxiom"
    FLYPROXY = "FlyProxy"
    FOGBUGZ = "Fogbugz"
    FOLDERA = "Foldera"
    FOLDERSHARE = "Foldershare"
    FOLDING_AT_HOME = "Folding at Home"
    FOONZ = "Foonz"
    FORTICLIENT_UPDATE = "FortiClient-update"
    FORWARD = "Forward"
    FOTKI = "Fotki"
    FOTOWEB = "FotoWeb"
    FOURSQUARE = "Foursquare"
    FOXY = "Foxy"
    FREECAST = "FreeCast"
    FREEETV = "FreeeTV"
    FREEGATE = "FreeGate"
    FRIEND_FEED = "Friend Feed"
    FRIENDSTER = "Friendster"
    FRING = "Fring"
    FROZENWAY = "FrozenWay"
    FS2YOU = "fs2you"
    FTP_PROTOCOL = "FTP Protocol"
    FUFOX = "FuFox"
    FUNSHION = "Funshion"
    FUZE_MEETING = "Fuze Meeting"
    FUZE_MEETING_FILE_SHARING = "Fuze Meeting-file sharing"
    FUZE_MEETING_DESKTOP_SHARING = "Fuze Meeting-desktop-sharing"
    FUZE_MEETING_BASE = "Fuze Meeting-base"
    GADU_GADU = "Gadu-Gadu"
    GAMESPY = "GameSpy"
    GARENA = "Garena"
    GATHERPLACE = "GatherPlace"
    GATHERPLACE_DESKTOP_SHARING = "GatherPlace-desktop sharing"
    GATHERPLACE_BASE = "GatherPlace-base"
    GBRIDGE = "Gbridge"
    GDB_REMOTE = "GDB remote"
    GDS_DB = "GDS-DB"
    GENESYS = "Genesys"
    GENESYS_DESKTOP_SHARING = "Genesys-desktop-sharing"
    GENESYS_BASE = "Genesys-base"
    GIGAUP = "Gigaup"
    GIT = "git"
    GIT_BASE = "git-base"
    GIT_UPLOADING = "git-uploading"
    GITHUB = "GitHub"
    GIZMO = "Gizmo"
    GLYPE_PROXY = "Glype Proxy"
    GMAIL = "Gmail"
    GMAIL_VIDEO_CHAT = "Gmail-video chat"
    GMAIL_CALL_PHONE = "Gmail-call-phone"
    GMAIL_ENTERPRISE = "Gmail-enterprise"
    GMAIL_CHAT = "Gmail-chat"
    GMAIL_BASE = "Gmail-base"
    GMAIL_DRIVE = "Gmail-drive"
    GNU_HTTPTUNNEL = "GNU-httptunnel"
    GNUNET = "GNUnet"
    GOGOBOX = "Gogobox"
    GOMEETNOW = "GoMeetNow"
    GOOD_FOR_ENTERPRISE = "Good for Enterprise"
    GOOGLE_ANALYTICS = "Google Analytics"
    GOOGLE_APP_ENGINE = "Google App Engine"
    GOOGLE_BUZZ = "Google Buzz"
    GOOGLE_CACHE = "Google Cache"
    GOOGLE_CALENDAR = "Google Calendar"
    GOOGLE_CALENDAR_ENTERPRISE = "Google Calendar-enterprise"
    GOOGLE_CALENDAR_BASE = "Google Calendar-base"
    GOOGLE_CLOUD_MESSAGING = "Google Cloud Messaging"
    GOOGLE_CLOUD_PRINT = "Google Cloud Print"
    GOOGLE_CLOUD_STORAGE = "Google Cloud Storage"
    GOOGLE_DESKTOP = "Google Desktop"
    GOOGLE_DOCS = "Google Docs"
    GOOGLE_DOCS_UPLOADING = "Google Docs-uploading"
    GOOGLE_DOCS_EDITING = "Google Docs-editing"
    GOOGLE_DOCS_ENTERPRISE = "Google Docs-enterprise"
    GOOGLE_DOCS_BASE = "Google Docs-base"
    GOOGLE_DRIVE_WEB = "Google Drive-web"
    GOOGLE_EARTH = "Google Earth"
    GOOGLE_FINANCE_POSTING = "Google Finance-posting"
    GOOGLE_KEEP = "Google Keep"
    GOOGLE_LIVELY = "Google Lively"
    GOOGLE_LOCATION_SERVICE = "Google Location Service"
    GOOGLE_MAPS = "Google Maps"
    GOOGLE_MUSIC = "Google Music"
    GOOGLE_PICASA = "Google Picasa"
    GOOGLE_PLAY = "Google Play"
    GOOGLE_PLUS = "Google Plus"
    GOOGLE_PLUS_POSTING = "Google Plus-posting"
    GOOGLE_PLUS_BASE = "Google Plus-base"
    GOOGLE_PLUS_EMAIL = "Google Plus Email"
    GOOGLE_SAFE_BROWSING = "Google Safe Browsing"
    GOOGLE_TALK = "Google Talk"
    GOOGLE_TALK_VOICE = "Google Talk-voice"
    GOOGLE_TALK_FILE_TRANSFER = "Google Talk-file transfer"
    GOOGLE_TALK_BASE = "Google Talk-base"
    GOOGLE_TALK_GADGET = "Google Talk Gadget"
    GOOGLE_TOOLBAR = "Google Toolbar"
    GOOGLE_TRANSLATE = "Google Translate"
    GOOGLE_TRANSLATE_MANUAL = "Google Translate-manual"
    GOOGLE_TRANSLATE_AUTO = "Google Translate-auto"
    GOOGLE_TRANSLATE_BASE = "Google Translate-base"
    GOOGLE_VIDEO = "Google Video"
    GOOGLE_VIDEO_ENTERPRISE = "Google Video-enterprise"
    GOOGLE_VIDEO_BASE = "Google Video-base"
    GOTOASSIST = "GoToAssist"
    GOTOMEETING = "GoToMeeting"
    GOTOMYPC_REMOTE_ACCESS = "GoToMyPC Remote Access"
    GOTOMYPC_REMOTE_CONTROL = "GoToMyPC-remote control"
    GOTOMYPC_DESKTOP_SHARING = "GoToMyPC-desktop sharing"
    GOTOMYPC_FILE_TRANSFER = "GoToMyPC-file transfer"
    GOTOMYPC_PRINTING = "GoToMyPC-printing"
    GOTOMYPC_BASE = "GoToMyPC-base"
    GPASS = "GPass"
    GPASS_PROXY = "GPass proxy"
    GRABOID_VIDEO = "Graboid Video"
    GRIDFTP = "GridFTP"
    GROOVESHARK = "grooveshark"
    GUARDSTER = "Guardster"
    GUILD_WARS = "Guild Wars"
    GYAO = "Gyao"
    HADOOP = "Hadoop"
    HADOOP_HBASE = "Hadoop-hbase"
    HADOOP_MAPREDUCE = "Hadoop-mapreduce"
    HADOOP_HDFS = "Hadoop-hdfs"
    HAMACHI = "Hamachi"
    HANGAME = "hangame"
    HBO = "HBO"
    HI5 = "Hi5"
    HIGHRISE = "Highrise"
    HIGHTAIL = "Hightail"
    HIGHTAIL_BASE = "Hightail-base"
    HIGHTAIL_UPLOAD = "Hightail-upload"
    HINET_WEBMAIL = "HiNet webmail"
    HIPCHAT = "HipChat"
    HL7 = "HL7"
    HONG_KONG_TOOLBAR = "Hong Kong Toolbar"
    HOOTSUITE = "HootSuite"
    HOPSTER = "Hopster"
    HORDE = "Horde"
    HOTFILE = "Hotfile"
    HOTLINE = "Hotline"
    HOTMAIL = "Hotmail"
    HOTSPOT_SHIELD = "Hotspot Shield"
    HOWARDFORUMS_POSTING = "HowardForums-posting"
    HP_DATA_PROTECTOR = "hp Data Protector"
    HP_EPRINT_SERVICE = "HP ePrint Service"
    HP_JETDIRECT = "HP Jetdirect"
    HP_UPDATE = "HP Update"
    HP_VIRTUAL_ROOMS = "HP Virtual Rooms"
    HTTP_AUDIO = "HTTP Audio"
    HTTP_NSRI = "HTTP Nsri"
    HTTP_PROXY = "HTTP Proxy"
    HTTP_TUNNEL = "HTTP Tunnel"
    HTTP_VIDEO = "HTTP Video"
    HTTPORT = "HTTPort"
    HULFT = "HULFT"
    HULU = "Hulu"
    HULU_POSTING = "Hulu-posting"
    HULU_BASE = "Hulu-base"
    HUSHMAIL = "Hushmail"
    HYVES = "Hyves"
    HYVES_GAMES = "Hyves-games"
    HYVES_MUSIC = "Hyves-music"
    HYVES_MAIL = "Hyves-mail"
    HYVES_CHAT = "Hyves-chat"
    HYVES_BASE = "Hyves-base"
    I2P = "I2P"
    IBACKUP = "IBackup"
    IBM_BIGFIX = "IBM BigFix"
    IBM_CLEARCASE = "IBM Clearcase"
    IBM_CLEARQUEST = "IBM Clearquest"
    IBM_DIRECTOR = "IBM Director"
    IBM_WEBSPHERE_MQ = "IBM Websphere-mq"
    ICLOUD = "iCloud"
    ICLOUD_BASE = "iCloud-base"
    ICLOUD_MAIL = "iCloud-mail"
    ICQ = "ICQ"
    ICQ2GO = "ICQ2Go"
    IEC_60870_5_104 = "IEC 60870-5-104"
    IEC_60870_5_104___BASE = "iec-60870-5-104 - Base"
    IEC_60870_5_104___PROCESS_MONITORING = "IEC 60870-5-104 - Process Monitoring"
    IEC_60870_5_104___PROCESS_CONTROL = "IEC 60870-5-104 - Process Control"
    IEC_60870_5_104___SYSTEM_MONITORING = "IEC 60870-5-104 - System Monitoring"
    IEC_60870_5_104___SYSTEM_CONTROL = "IEC 60870-5-104 - System Control"
    IEC_60870_5_104___PARAMETER_CONTROL = "IEC 60870-5-104 - Parameter Control"
    IEC_60870_5_104___SUPERVISORY = "IEC 60870-5-104 - Supervisory"
    IEC_60870_5_104___UNNUMBERED = "IEC 60870-5-104 - Unnumbered"
    _ASDU___FILE_TRANSFER = "104asdu - File Transfer"
    IEC_61850 = "IEC-61850"
    IEC_61850_BASE = "IEC-61850-base"
    IEC_61850_GETDATADIR = "IEC-61850-getdatadir"
    IEC_61850_DELETE_NAMED_VAR_LIST = "IEC-61850-delete-named-var-list"
    IEEE_C37_118_SYNCHROPHASOR = "IEEE C37.118 Synchrophasor"
    IFILE_IT = "iFile.it"
    IFOLDER = "iFolder"
    IHEARTRADIO = "iheartradio"
    ILOHAMAIL = "IlohaMail"
    ILOVEIM = "ILoveIM"
    IMEET = "iMeet"
    IMEET_FILE_TRANSFER = "iMeet-file transfer"
    IMEET_BASE = "Imeet-base"
    IMESH = "iMesh"
    IMVU = "IMVU"
    INFORMIX = "Informix"
    INSTAGRAM = "Instagram"
    INSTAN_T = "Instan-t"
    INSTAN_T_FILE_TRANSFER = "Instan-t-file transfer"
    INSTAN_T_BASE = "Instan-t-base"
    IP_MESSENGER = "IP Messenger"
    IP_MESSENGER_FILE_TRANSFER = "IP-Messenger-file-transfer"
    IP_MESSENGER_BASE = "IP-Messenger-base"
    IPERF = "Iperf"
    IPSEC = "IPsec"
    IPSEC_AH = "IPsec-ah"
    IPSEC_ESP_UDP = "IPsec-esp-udp"
    IPSEC_ESP = "IPsec-esp"
    IKE_PROTOCOL = "IKE Protocol"
    IRC_PROTOCOL = "IRC Protocol"
    IRC_BASE = "IRC-base"
    IRC_DCC_CHAT = "IRC-dcc-chat"
    IRC_DCC_FILE_TRANSFER = "IRC-dcc-file-transfer"
    IRC_DCC_WHITEBOARD = "IRC-dcc-whiteboard"
    IRODS = "iRODS"
    ISL_LIGHT = "ISL Light"
    ISSUU = "Issuu"
    ISSUU_UPLOADING = "Issuu-uploading"
    ISSUU_BASE = "Issuu-base"
    ITUNES = "iTunes"
    ITUNES_APPSTORE = "iTunes-appstore"
    ITUNES_MEDIASTORE = "iTunes-mediastore"
    ITUNES_BASE = "iTunes-base"
    JANGO = "jango"
    JAP = "Jap"
    JASPERSOFT = "Jaspersoft"
    JAVA_UPDATE = "Java Update"
    JIRA = "JIRA"
    JOIN_ME = "join.me"
    JOIN_ME_FILE_TRANSFER = "join.me-file-transfer"
    JOIN_ME_BASE = "join.me-base"
    JOOST = "Joost"
    JUBII = "Jubii"
    JUNGLE_DISK = "Jungle Disk"
    JUSTIN_TV = "Justin.tv"
    KAIXIN = "Kaixin"
    KAIXIN_MAIL = "Kaixin-mail"
    KAIXIN_CHAT = "Kaixin-chat"
    KAIXIN_BASE = "Kaixin-base"
    KAIXIN001 = "Kaixin001"
    KAIXIN001_MAIL = "Kaixin001-mail"
    KAIXIN001_BASE = "Kaixin001-base"
    KAKAOTALK = "KakaoTalk"
    KAKAOTALK_AUDIO_CHAT = "KakaoTalk-audio-chat"
    KAKAOTALK_BASE = "KakaoTalk-base"
    KAKAOTALK_FILE_TRANSFER = "KakaoTalk-file-transfer"
    KANBAN_TOOL = "Kanban Tool"
    KASEYA = "Kaseya"
    KAZAA = "Kazaa"
    KEEK = "Keek"
    KEYHOLETV = "KeyHoleTV"
    KIK = "Kik"
    KINO = "Kino"
    KIWOOM_HTS = "Kiwoom-hts"
    KKBOX = "KKBOX"
    KNIGHT_ONLINE = "Knight Online"
    KOOL_IM = "Kool IM"
    KOREA_WEBMAIL = "Korea-webmail"
    KPROXY = "Kproxy"
    KU6 = "ku6"
    KUGOO = "Kugoo"
    L2TP_PROTOCOL = "L2TP Protocol"
    LABNOL_PROXY = "labnol-proxy"
    LACONICA = "Laconica"
    LAIWANG = "Laiwang"
    LAIWANG_BASE = "Laiwang-base"
    LAIWANG_FILE_TRANSFER = "Laiwang-file-transfer"
    LANDESK = "LANDesk"
    LASTPASS = "LastPass"
    LEAPFILE = "LeapFile"
    LETV = "Letv"
    LIBERO_VIDEO = "Libero Video"
    LINEAGE = "Lineage"
    LINKEDIN = "LinkedIn"
    LINKEDIN_APPS = "LinkedIn-apps"
    LINKEDIN_POSTING = "LinkedIn-posting"
    LINKEDIN_MAIL = "LinkedIn-mail"
    LINKEDIN_BASE = "LinkedIn-base"
    LITECOIN = "Litecoin"
    LIVE365 = "live365"
    LIVEJOURNAL = "LiveJournal"
    LIVELINKS = "LiveLinks"
    LIVE_MESH = "Live Mesh"
    LIVE_MESH_REMOTE_DESKTOP = "Live Mesh-remote-desktop"
    LIVE_MESH_SYNC = "Live Mesh-sync"
    LIVE_MESH_BASE = "Live Mesh-base"
    LIVEPERSON = "LivePerson"
    LIVESTATION = "Livestation"
    LIVESTREAM = "Livestream"
    LOGMEIN = "LogMeIn"
    LOGMEIN_RESCUE = "LogMeIn rescue"
    LOKALISTEN = "lokalisten"
    LOOKOUT = "Lookout"
    LOTUS_NOTES = "Lotus Notes"
    LOTUS_NOTES_ADMIN = "Lotus Notes-admin"
    LOTUS_NOTES_BASE = "Lotus Notes-base"
    LOTUSLIVE = "LotusLive"
    LOTUSLIVE_INOTES = "LotusLive-inotes"
    LOTUSLIVE_FILE_SHARING = "LotusLive-file sharing"
    LOTUSLIVE_BASE = "LotusLive-base"
    LOTUSLIVE_MEETING_APPS_SHARING = "LotusLive-meeting-apps-sharing"
    LOTUSLIVE_MEETING_FILE_SHARING = "LotusLive-meeting-file sharing"
    MAGFS = "MagFS"
    MAGISTER = "Magister"
    MAIL_COM = "Mail.com"
    MAIL_RU = "Mail.Ru"
    MAIL_RU_GAMES = "Mail.Ru-games"
    MAIL_RU_BASE = "Mail.Ru-base"
    MAIL_RU_MOIMIR = "Mail.Ru-moimir"
    MAIL_RU_MAIL = "Mail.Ru-mail"
    MAIL_RU_AGENT = "Mail.Ru Agent"
    MAIL_RU_AGENT_BASE = "Mail.Ru Agent-base"
    MAIL_RU_AGENT_FILE_TRANSFER = "Mail.Ru Agent-file transfer"
    MAIL_RU_WEBAGENT = "Mail.Ru WebAgent"
    MANOLITO = "Manolito"
    MAPLESTORY = "MapleStory"
    MARKET_Q = "Market-Q"
    MARKLOGIC_XDBC = "MarkLogic-XDBC"
    MCAFEE_UPDATE = "McAfee-update"
    ME2DAY = "Me2Day"
    MEDIAFIRE = "MediaFire"
    MEDIAMAX = "MediaMax"
    MEEBO = "Meebo"
    MEEBO_FILE_TRANSFER = "Meebo-file-transfer"
    MEEBO_BASE = "Meebo-base"
    MEEBOME = "MeeboMe"
    MEETUP = "Meetup"
    MEETUP_EMAIL = "meetup-email"
    MEETUP_BASE = "Meetup-base"
    MEETUP_FORUM = "Meetup-forum"
    MEEVEE = "MeeVee"
    MEGA = "Mega"
    MEGAPROXY = "Megaproxy"
    MEGASHARE = "Megashare"
    MEGAUPLOAD = "Megaupload"
    MEGAVIDEO = "Megavideo"
    MEINVZ = "meinvz"
    MEKUSHARIM = "Mekusharim"
    MENDELEY = "Mendeley"
    MESSENGERFX = "MessengerFX"
    METACAFE = "Metacafe"
    METATRADER = "Metatrader"
    MGOON = "mgoon"
    MIBBIT = "Mibbit"
    MICROSOFT_DYNAMICS_CRM = "Microsoft Dynamics CRM"
    MIKOGO = "Mikogo"
    MINECRAFT = "MineCraft"
    MIRO = "Miro"
    MIXI = "Mixi"
    MIXI_POSTING = "Mixi-posting"
    MIXI_BASE = "Mixi-base"
    MLB_TV = "MLB.tv"
    MMS_PROTOCOL = "MMS Protocol"
    MOBILEME = "MobileMe"
    MOCHA_RDP = "Mocha-RDP"
    MODBUS_PROTOCOL = "Modbus Protocol"
    MODBUS_READ_HOLDING_REGISTERS = "Modbus-read-holding-registers"
    MODBUS_READ_FILE_RECORD = "Modbus-read file record"
    MODBUS_READ_FIFO_QUEUE = "Modbus-read FIFO queue"
    MODBUS_MASK_WRITE_REGISTER = "Modbus-mask write register"
    MODBUS_READ_DISCRETE_INPUTS = "Modbus-read discrete inputs"
    MODBUS_READ_COILS = "Modbus-read coils"
    MODBUS_ENCAPSULATED_TRANSPORT = "Modbus-encapsulated transport"
    MODBUS_READ_INPUT_REGISTER = "Modbus-read input register"
    MODBUS_READ_WRITE_MULTIPLE_REGISTERS = "Modbus-read-write multiple registers"
    MODBUS_WRITE_SINGLE_REGISTER = "Modbus-write single register"
    MODBUS_WRITE_SINGLE_COIL = "Modbus-write single coil"
    MODBUS_READ_WRITE_REGISTER = "Modbus-read-write-register"
    MODBUS_WRITE_FILE_RECORD = "Modbus-write-file-record"
    MODBUS_WRITE_MULTIPLE_COILS = "Modbus-write-multiple-coils"
    MODBUS_BASE = "Modbus-base"
    MOGULUS = "Mogulus"
    MONGODB = "MongoDB"
    MOINMOIN_EDITING = "MoinMoin editing"
    MORNINGSTAR_POSTING = "Morningstar-posting"
    MOZY = "mozy"
    MS_DS_SMB = "Ms-ds-smb"
    MICROSOFT_LYNC = "Microsoft Lync"
    MICROSOFT_LYNC_APPS_SHARING = "Microsoft Lync-apps-sharing"
    MICROSOFT_LYNC_FILE_TRANSFER = "Microsoft Lync-file-transfer"
    MICROSOFT_LYNC_VIDEO = "Microsoft Lync-video"
    MICROSOFT_LYNC_AUDIO = "Microsoft Lync-audio"
    MICROSOFT_LYNC_BASE = "Microsoft Lync-base"
    NETLOGON = "Netlogon"
    MS_OCS = "MS-ocs"
    MS_OCS_AUDIO = "MS-ocs-audio"
    MS_OCS_FILE_TRANSFER = "MS-ocs-file-transfer"
    MS_OCS_VIDEO = "MS-ocs-video"
    MS_OFFICE365 = "MS-office365"
    MS_OFFICE365_BASE = "MS-office365-base"
    OFFICE_ON_DEMAND = "Office on Demand"
    OUTLOOK_WEB_ONLINE = "Outlook Web Online"
    MICROSOFT_LYNC_ONLINE = "Microsoft Lync Online"
    MICROSOFT_LYNC_ONLINE_APPS_SHARING = "Microsoft Lync Online-apps-sharing"
    SHAREPOINT_ONLINE = "SharePoint Online"
    MICROSOFT_LYNC_FILE_TRANSFER2 = "Microsoft Lync File Transfer"
    MS_PRODUCT_ACTIVATION = "MS Product Activation"
    MICROSOFT_RDP = "Microsoft RDP"
    MS_SCHEDULER = "MS Scheduler"
    SYSTEM_CENTER_OPERATIONS_MANAGER = "System Center Operations Manager"
    MICROSOFT_SERVICE_CONTROLLER = "Microsoft Service Controller"
    SYSTEM_CENTER_CONFIGURATION_MANAGER = "System Center Configuration Manager"
    MICROSOFT_SPYNET = "Microsoft SpyNet"
    MICROSOFT_SQL_SERVER_ANALYSIS_SERVICES = "Microsoft SQL Server Analysis Services"
    SSTP = "SSTP"
    WINDOWS_UPDATE = "Windows Update"
    MICROSOFT_VIRTUAL_SERVER = "Microsoft Virtual Server"
    MICROSOFT_VISUAL_STUDIO_TFS = "Microsoft Visual Studio TFS"
    MS_WIN_DNS = "MS-WIN DNS"
    MS_WINS = "MS-WINS"
    MSN = "MSN"
    MSN_VOICE = "MSN-voice"
    MSN_VIDEO = "MSN-video"
    MSN_FILE_TRANSFER = "MSN-file-transfer"
    MSN_BASE = "MSN-base"
    MSN2GO = "MSN2Go"
    MSSQL_DB = "Mssql-db"
    MSSQL_MON = "Mssql-mon"
    MUTE = "Mute"
    MYDOWNLOADER = "MyDownloader"
    MYGREENPC = "MyGreenPC"
    MYSPACE = "MySpace"
    MYSPACE_POSTING = "MySpace-posting"
    MYSPACE_BASE = "MySpace Base"
    MYSPACE_VIDEO = "MySpace Video"
    MYSPACEIM = "MySpaceIM"
    MYSPACE_MAIL = "MySpace Mail"
    MYSQL_PROTOCOL = "MySQL Protocol"
    NAGIOS = "Nagios"
    NAKIDO_FLAG = "Nakido Flag"
    NAPSTER = "Napster"
    NATE_VIDEO = "Nate-video"
    NATEON_IM = "NateOn-IM"
    NATEON_IM_BASE = "NateOn-IM-base"
    NATEON_DESKTOP_SHARING = "NateOn-desktop sharing"
    NATEON_AUDIO_VIDEO = "NateOn-audio video"
    NATEON_FILE_TRANSFER = "NateOn-file transfer"
    NAVER_MAIL = "Naver Mail"
    NAVER_NDRIVE = "Naver Ndrive"
    NBC_VIDEO = "NBC-video"
    NEFSIS = "Nefsis"
    NETBIOS_NAME_SERVICE = "NetBIOS Name Service"
    NETBIOS_SESSION_SERVICE = "NetBIOS Session Service"
    NETBOTZ = "NetBotz"
    NETEASE_MAIL = "Netease Mail"
    NETFLIX = "Netflix"
    NETFLIX_STREAMING = "Netflix-streaming"
    NETFLIX_BASE = "Netflix-base"
    NETFOLDER = "NetFolder"
    NETLOAD = "Netload"
    NETLOG = "Netlog"
    NETOP_REMOTE_CONTROL = "Netop Remote Control"
    NETSUITE = "Netsuite"
    NETVIEWER = "Netviewer"
    NEW_RELIC = "New Relic"
    NEXTMEDIA_VIDEO = "NEXTmedia-video"
    NFS_PROTOCOL = "NFS Protocol"
    NGROK = "Ngrok"
    NICO_NICO_DOUGA = "Nico Nico-Douga"
    NIMBUZZ = "Nimbuzz"
    NING = "Ning"
    NING_APPS = "Ning-apps"
    NING_MAIL = "Ning-mail"
    NING_POSTING = "Ning-posting"
    NING_BASE = "Ning-base"
    NNTP_PROTOCOL = "NNTP Protocol"
    NORTON_ZONE = "Norton Zone"
    NOTEWORTHY = "Noteworthy"
    NOTEWORTHY_ADMIN = "Noteworthy-admin"
    NOTEWORTHY_BASE = "Noteworthy-base"
    NOVELL_FILR = "Novell Filr"
    NTP_PROTOCOL = "NTP Protocol"
    NTR_SUPPORT = "NTR Support"
    OCSP_PROTOCOL = "OCSP Protocol"
    OCTOPZ = "Octopz"
    OCTOSHAPE = "Octoshape"
    ODNOKLASSNIKI = "Odnoklassniki"
    ODNOKLASSNIKI_APPS = "Odnoklassniki-apps"
    ODNOKLASSNIKI_MESSAGING = "Odnoklassniki-messaging"
    ODNOKLASSNIKI_BASE = "Odnoklassniki-base"
    OKURIN = "Okurin"
    OMEGLE = "Omegle"
    OMNIDRIVE = "Omnidrive"
    ONEHUB = "Onehub"
    ONEHUB_BASE = "Onehub-base"
    ONEHUB_UPLOADING = "Onehub-uploading"
    ONLIVE = "OnLive"
    ONTV = "ONtv"
    OOVOO = "ooVoo"
    OOYALA = "Ooyala"
    OPEN_WEBMAIL = "Open Webmail"
    OPENDOOR = "OpenDoor"
    OPENFT = "OpenFT"
    OPENOMY = "Openomy"
    OPERA_MINI = "Opera Mini"
    OPTIMUM_WEBMAIL = "Optimum Webmail"
    ORACLE = "Oracle"
    ORB = "Orb"
    ORIGIN = "Origin"
    ORKUT = "Orkut"
    OSISOFT_PI = "OSIsoft PI"
    OSSEC = "OSSEC"
    OWNCLOUD = "ownCloud"
    P10 = "P10"
    PACKETIX_VPN = "PacketiX VPN"
    PAGEKITE = "PageKite"
    PALTALK = "Paltalk"
    PALTALK_SUPERIM = "Paltalk SuperIM"
    PALTALK_FILE_TRANSFER = "Paltalk-file transfer"
    PALTALK_BASE = "Paltalk-base"
    PALTALK_EXPRESS = "Paltalk Express"
    PANDO = "Pando"
    PANDORA = "Pandora"
    PANDORA_TV = "Pandora-TV"
    PANORAMA = "Panorama"
    PANOS_GLOBAL_PROTECT = "PANOS Global Protect"
    PANOS_WEB_INTERFACE = "PANOS Web Interface"
    PARADISE_PAINTBALL = "Paradise Paintball"
    PARAN_MAIL = "Paran Mail"
    PARAN_U2 = "Paran-U2"
    PARTY_POKER = "Party Poker"
    PASTEBIN = "Pastebin"
    PASTEBIN_BASE = "Pastebin-base"
    PASTEBIN_POSTING = "Pastebin-posting"
    PATH = "Path"
    PATHVIEW = "PathView"
    PCANYWHERE = "pcAnywhere"
    PCANYWHERE_REMOTE_CONTROL = "pcAnywhere-remote control"
    PCANYWHERE_FILE_TRANSFER = "pcAnywhere-file transfer"
    PCANYWHERE_BASE = "pcAnywhere-base"
    PCVISIT = "Pcvisit"
    PEERCAST = "Peercast"
    PENTAHO = "Pentaho"
    PERFORCE = "Perforce"
    PHONEMYPC = "PhoneMyPc"
    PHOTOBUCKET = "Photobucket"
    PHWEET = "Phweet"
    PICHAT = "Pichat"
    PINTEREST = "Pinterest"
    PLAXO = "Plaxo"
    PLAYSTATION_NETWORK = "Playstation Network"
    PLURK = "Plurk"
    PODIO = "Podio"
    POGO = "Pogo"
    POWNCE = "Pownce"
    POWOW = "Powow"
    POWOW_BASE = "Powow-base"
    POWOW_FILE_TRANSFER = "Powow-file-transfer"
    PP_ACCELERATOR = "PP-accelerator"
    PPI_MEDIA = "ppi Media"
    PPLIVE = "PPlive"
    PPSTREAM = "PPStream"
    PPTP_PROTOCOL = "PPTP Protocol"
    PREZI = "Prezi"
    PRIVAX = "privax"
    PROJECTPLACE = "Projectplace"
    PROXEASY = "ProxEasy"
    PROXONO = "Proxono"
    PSIPHON = "Psiphon"
    PULLBBANG_VIDEO = "Pullbbang-video"
    PURPLE_P3 = "Purple-P3"
    PUTLOCKER = "PutLocker"
    QDOWN = "Qdown"
    QIANLONG = "Qianlong"
    QIK = "Qik"
    QIK_UPLOADING = "Qik-uploading"
    QIK_VIDEO_CHATTING = "Qik-video-chatting"
    QIK_POSTING = "Qik-posting"
    QIK_SHARING = "Qik-sharing"
    QIK_VIEWING = "Qik-viewing"
    QIK_BASE = "Qik-base"
    QQ = "QQ"
    QQ_AUDIO_VIDEO = "QQ-audio-video"
    QQ_FILE_TRANSFER = "QQ-file-transfer"
    QQ_BASE = "QQ-base"
    QQ_DOWNLOAD = "QQ Download"
    QQ_GAMES = "QQ Games"
    QQ_MAIL = "QQ Mail"
    QQ_LIVE = "QQ Live"
    QQ_MUSIC = "QQ Music"
    QUORA = "Quora"
    REXEC_PROTOCOL = "REXEC Protocol"
    RABBITMQ = "RabbitMQ"
    RADIUS_PROTOCOL = "RADIUS Protocol"
    RADMIN = "Radmin"
    RAGING_BULL_POSTING = "Raging Bull-posting"
    RAPIDSHARE = "Rapidshare"
    RAZOR = "Razor"
    RDIO = "Rdio"
    RDM_PLUS = "RDM Plus"
    RDP2TCP = "rdp2tcp"
    RDT = "RDT"
    READYTALK = "ReadyTalk"
    READYTALK_CHAT = "ReadyTalk-chat"
    READYTALK_DESKTOP_SHARING = "ReadyTalk-desktop-sharing"
    READYTALK_BASE = "ReadyTalk-base"
    REBTEL = "Rebtel"
    REDBOX_INSTANT = "Redbox-Instant"
    REDIFF_BOL = "Rediff Bol"
    REDIFF_BOL_AUDIO_VIDEO = "Rediff Bol-audio-video"
    REDIFF_BOL_BASE = "Rediff Bol-base"
    REDIFF_BOL_FILE_TRANSFER = "Rediff Bol-file transfer"
    REDIS = "Redis"
    REDUH = "ReDuh"
    REMOBO = "Remobo"
    REMOTECALL = "RemoteCall"
    REMOTEVIEW = "RemoteView"
    RENREN = "Renren"
    RENREN_POSTING = "Renren-posting"
    RENREN_MUSIC = "Renren-music"
    RENREN_MAIL = "Renren-mail"
    RENREN_CHAT = "Renren-chat"
    RENREN_APPLICATIONS = "Renren-applications"
    RENREN_BASE = "Renren-base"
    RENREN_IM = "Renren IM"
    RES_AUTOMATION_MANAGER = "RES Automation Manager"
    RETROSHARE = "RetroShare"
    RHAPSODY = "Rhapsody"
    RIFT = "Rift"
    RLOGIN = "Rlogin"
    ROBOFORM = "RoboForm"
    ROUNDCUBE = "Roundcube"
    ROVER = "Rover"
    RPC = "RPC"
    RPC_OVER_HTTP = "RPC over HTTP"
    RSH = "rsh"
    RSS = "RSS"
    RSYNC = "rsync"
    RTCP_PROTOCOL = "RTCP Protocol"
    RTMFP = "RTMFP"
    RTMP = "RTMP"
    RTMPE = "RTMPE"
    RTMPT = "RTMPT"
    RTP_PROTOCOL = "RTP Protocol"
    RUNESCAPE = "RuneScape"
    RYPPLE = "Rypple"
    SAKAI = "Sakai"
    SALESFORCE = "Salesforce"
    SALESFORCE_CHATTER = "Salesforce Chatter"
    SALESFORCE_BASE = "Salesforce-base"
    SAMSUNG_UPDATES = "Samsung-updates"
    SAP = "SAP"
    SBS_NETV = "SBS-NeTV"
    SCHMEDLEY = "Schmedley"
    SCRIBD = "Scribd"
    SCRIBD_UPLOADING = "Scribd-uploading"
    SCRIBD_BSAE = "Scribd-bsae"
    SECOND_LIFE = "Second Life"
    SECOND_LIFE_VOICE_CHAT = "Second Life-voice chat"
    SECOND_LIFE_BASE = "Second Life-base"
    SECURE_ACCESS = "Secure Access"
    SEESMIC = "Seesmic"
    SENDOID = "Sendoid"
    SENDSPACE = "Sendspace"
    SFLOW = "sFlow"
    SHAREFILE = "ShareFile"
    SHAREFILE_BASE = "ShareFile-base"
    SHAREFILE_UPLOADING = "ShareFile-uploading"
    SHAREPOINT = "SharePoint"
    SHAREPOINT_WIKI = "SharePoint-wiki"
    SHAREPOINT_ADMIN = "SharePoint-admin"
    SHAREPOINT_CALENDAR = "SharePoint-calendar"
    SHAREPOINT_DOCUMENTS = "SharePoint-documents"
    SHAREPOINT_BASE = "SharePoint-base"
    SHAREPOINT_BLOG_POSTING = "SharePoint-blog-posting"
    SHOUTCAST = "SHOUTcast"
    SHOWMYPC = "ShowMyPC"
    SHUTTERFLY = "Shutterfly"
    SIEBEL_CRM = "Siebel CRM"
    SIGHTSPEED = "SightSpeed"
    SIGNIANT = "Signiant"
    SIGNIANT_BASE = "Signiant-base"
    SIGNIANT_UPLOADING = "Signiant-uploading"
    SIGNNOW = "Signnow"
    SILVERLIGHT = "Silverlight"
    SIMPLENOTE = "Simplenote"
    SIMPLITE_MSN = "Simplite-msn"
    SINA_UC = "Sina UC"
    SINA_UC_WEB_DISK = "Sina UC-web-disk"
    SINA_UC_REMOTE_CONTROL = "Sina UC-remote control"
    SINA_UC_AUDIO_VIDEO = "Sina UC-audio video"
    SINA_UC_FILE_TRANSFER = "Sina UC-file transfer"
    SINA_UC_BASE = "Sina UC-base"
    SINA_WEIBO = "Sina-Weibo"
    SINA_WEIBO_POSTING = "Sina-Weibo-posting"
    SINA_WEIBO_BASE = "Sina-Weibo-base"
    MICROSOFT_SKYDRIVE = "Microsoft SkyDrive"
    MICROSOFT_SKYDRIVE_BASE = "Microsoft SkyDrive-base"
    MICROSOFT_SKYDRIVE_UPLOAD = "Microsoft SkyDrive-upload"
    SKYDUR = "Skydur"
    SKYPE = "Skype"
    SLACKER = "slacker"
    SLIDEROCKET = "SlideRocket"
    SLIDESHARE = "SlideShare"
    SLIDESHARE_BASE = "SlideShare-base"
    SLIDESHARE_UPLOAD = "SlideShare-upload"
    SLP = "SLP"
    SMART_BRIDGIT = "Smart Bridgit"
    SMILEBOX = "Smilebox"
    SMTP_PROTOCOL = "SMTP Protocol"
    SMUGMUG = "Smugmug"
    SNAPCHAT = "Snapchat"
    SNAPFISH = "Snapfish"
    SNMP_PROTOCOL = "SNMP Protocol"
    SNMPV3 = "SNMPv3"
    SNMPV2 = "SNMPv2"
    SNMPV1 = "SNMPv1"
    SNMP_BASE = "SNMP-base"
    SNMP_TRAP = "SNMP Trap"
    SNPP_PROTOCOL = "SNPP Protocol"
    SOAP = "SOAP"
    SOCIALCAM = "Socialcam"
    SOCKS2HTTP = "Socks2HTTP"
    SOFTROS_MESSENGER = "Softros Messenger"
    SOFTROS_MESSENGER_FILE_TRANSFER = "Softros Messenger-file transfer"
    SOFTROS_MESSENGER_BASE = "Softros Messenger-base"
    SOHU_VIDEO = "Sohu-video"
    SOPCAST = "Sopcast"
    SOPHOS_RMS = "Sophos-RMS"
    SOPHOS_UPDATE = "Sophos-update"
    SORIBADA = "Soribada"
    SOULSEEK = "SoulSeek"
    SOUNDCLOUD = "SoundCloud"
    SOUNDCLOUD_BASE = "SoundCloud-base"
    SOUNDCLOUD_UPLOADING = "SoundCloud-uploading"
    SOURCEFORGE = "SourceForge"
    SPARK = "Spark"
    SPARK_IM = "Spark IM"
    SPARK_IM_BASE = "Spark IM-base"
    SPARK_IM_FILE_TRANSFER = "Spark IM-file-transfer"
    SPEEDTEST = "Speedtest"
    SPIDEROAK = "SpiderOak"
    SPIRENT = "Spirent"
    SPLASHTOP_REMOTE = "Splashtop Remote"
    SPLUNK = "Splunk"
    SPOTFLUX = "spotflux"
    SPOTIFY = "Spotify"
    SPOTNET = "Spotnet"
    SPRINGCM = "SpringCM"
    SQUARE = "Square"
    SQUIRRELMAIL = "SquirrelMail"
    SSDP = "SSDP"
    SSH_PROTOCOL = "SSH Protocol"
    SSH_TUNNEL = "SSH Tunnel"
    SSL_PROTOCOL = "SSL Protocol"
    STAGEVU = "stagevu"
    STEALTHNET = "StealthNet"
    STEAM = "Steam"
    STICKAM = "Stickam"
    STOCKSTAR = "StockStar"
    STORAGE_TO = "STORAGE.to"
    STRATUM_MINING_PROTOCOL = "Stratum mining protocol"
    STREAMAUDIO = "Streamaudio"
    STREAMBOX = "Streambox"
    STREAMPIX = "Streampix"
    STUDIVZ = "StudiVZ"
    STUMBLEUPON = "StumbleUpon"
    STUN_PROTOCOL = "STUN Protocol"
    SUGARCRM = "SugarCRM"
    SUGARSYNC = "Sugarsync"
    SUPREMO = "Supremo"
    SURESOME = "Suresome"
    SURROGAFIER = "Surrogafier"
    SVT_PLAY = "SVT Play"
    SYMANTEC_UPDATE = "Symantec-update"
    SYNCPLICITY = "Syncplicity"
    SYSLOG_PROTOCOL = "Syslog Protocol"
    T_ONLINE_MAIL = "T-online Mail"
    T_120_PROTOCOL = "T.120 Protocol"
    T_38 = "T.38"
    TABLEAU = "Tableau"
    TABLEAU_PUBLIC = "Tableau Public"
    TACACS_PROTOCOL = "TACACS Protocol"
    TACACS_ = "TACACS+"
    TAGOO = "Tagoo"
    TALES_RUNNER = "Tales Runner"
    TALKBOX = "TalkBox"
    TANGO = "Tango"
    TANIUM = "Tanium"
    TCP_OVER_DNS = "TCP-over-DNS"
    TEACHERTUBE = "TeacherTube"
    TEAMSPEAK = "TeamSpeak"
    TEAMVIEWER = "TeamViewer"
    TEAMVIEWER_REMOTE_CONTROL = "TeamViewer-remote-control"
    TEAMVIEWER_SHARING = "TeamViewer-sharing"
    TEAMVIEWER_BASE = "TeamViewer-base"
    TELENET_WEBMAIL = "Telenet-WebMail"
    TELNET_PROTOCOL = "Telnet Protocol"
    TERRARIA = "Terraria"
    THWAPR = "Thwapr"
    THWAPR_SHARING = "Thwapr-sharing"
    THWAPR_UPLOADING = "Thwapr-uploading"
    THWAPR_BASE = "Thwapr-base"
    TIBBR = "Tibbr"
    TIDALTV = "TidalTV"
    TIKIWIKI_EDIT = "TikiWiki-edit"
    TINYVPN = "TinyVPN"
    TISCALI_MAIL = "Tiscali-mail"
    TOKBOX = "Tokbox"
    TONGHUASHUN = "Tonghuashun"
    TOR = "Tor"
    TOR2WEB = "Tor2Web"
    TRILLIAN = "Trillian"
    TRIPPY = "Trippy"
    TUDOU = "TUDOU"
    TUDOU_SPEEDUP = "Tudou-speedup"
    TUENTI = "Tuenti"
    TUMBLR = "Tumblr"
    TUMBLR_POSTING = "Tumblr-posting"
    TUMBLR_BASE = "Tumblr-base"
    TUNEIN = "TuneIn"
    TUNNELBEAR = "TunnelBear"
    TV4_PLAY = "TV4 Play"
    TVANTS = "TvAnts"
    TWILIO = "Twilio"
    TWITPIC = "Twitpic"
    TWITTER = "Twitter"
    TWITTER_BASE = "Twitter-base"
    TWITTER_POSTING = "Twitter-posting"
    TWTKR = "Twtkr"
    UBERCONFERENCE = "UberConference"
    UBUNTU_ONE = "Ubuntu One"
    ULTRASURF = "Ultrasurf"
    UNISTIM = "UNIStim"
    UNITRENDS = "Unitrends"
    USEJUMP = "Usejump"
    USTREAM = "Ustream"
    UUSEE = "UUSee"
    VAGAA = "Vagaa"
    VAKAKA = "Vakaka"
    VBULLETIN_POSTING = "vBulletin-posting"
    VEETLE = "Veetle"
    VENTRILO = "Ventrilo"
    VIA3 = "VIA3"
    VIADEO = "Viadeo"
    VIBER = "Viber"
    VIBER_VOICE = "Viber-voice"
    VIBER_BASE = "Viber-base"
    VIDDY = "Viddy"
    VIMEO = "Vimeo"
    VIMEO_BASE = "Vimeo-base"
    VIMEO_UPLOADING = "Vimeo-uploading"
    VINE = "Vine"
    VINE_BASE = "Vine-base"
    VINE_POSTING = "Vine-posting"
    VIPNET_VPN = "ViPNet VPN"
    VIRUSTOTAL = "Virustotal"
    VKONTAKTE = "Vkontakte"
    VKONTAKTE_MAIL = "Vkontakte-mail"
    VKONTAKTE_CHAT = "Vkontakte-chat"
    VKONTAKTE_BASE = "Vkontakte-base"
    VMWARE = "VMware"
    VMWARE_VIEW = "VMware View"
    VMWARE_VMOTION = "VMware VMotion"
    VNC = "VNC"
    VNC_PRINT = "VNC-print"
    VNC_ENCYPTED = "VNC-encypted"
    VNC_CLIPBOARD = "VNC-clipboard"
    VNC_FILE_TRANSFER = "VNC-file transfer"
    VNC_BASE = "VNC-base"
    VNC_CHAT = "VNC-chat"
    VNC_HTTP = "VNC-http"
    VNN = "VNN"
    VODDLER = "Voddler"
    VSEE = "VSee"
    VTUN = "Vtun"
    VTUNNEL = "VTunnel"
    VUDU = "Vudu"
    VXLAN = "VXLAN"
    VYEW = "Vyew"
    VZOCHAT = "VZOchat"
    WALLCOOLER_VPN = "WallCooler VPN"
    WAR_ROCK = "War Rock"
    WAR2_GLORY = "WAR2 Glory"
    WATCHDOX = "Watchdox"
    WAZE = "Waze"
    WE_DANCING_ONLINE = "We Dancing Online"
    WEB_BROWSING = "Web-browsing"
    WEBEX = "WebEx"
    WEBEX_CHAT = "WebEx Chat"
    WEBEX_WHITEBOARD = "WebEx Whiteboard"
    WEBEX_DESKTOP_SHARING = "WebEx Desktop Sharing"
    WEBEX_BASE = "WebEx Base"
    WEBEX_FILE_SHARING = "WebEx File Sharing"
    WEBEX_CONNECT = "WebEx Connect"
    WEBEX_WEBOFFICE = "WebEx WebOffice"
    WEB_QQ = "Web QQ"
    WEBRDP = "webRDP"
    WEBSENSE = "Websense"
    WEBSHOTS = "Webshots"
    WEBSOCKET_PROTOCOL = "WebSocket Protocol"
    WECHAT = "WeChat"
    WECHAT_BASE = "WeChat-base"
    WECHAT_VIDEO = "WeChat-video"
    WECHAT_FILE_TRANSFER = "WeChat-file-transfer"
    WETPAINT_EDITING = "Wetpaint-editing"
    WETRANSFER = "WeTransfer"
    WHATSAPP = "WhatsApp"
    WHATSAPP_BASE = "WhatsApp-base"
    WHATSAPP_MESSENGER_FILE_TRANSFER = "WhatsApp Messenger-file transfer"
    WHOIS = "WHOIS"
    WIICONNECT24 = "WiiConnect24"
    WIKIDOT_EDIT = "Wikidot-edit"
    WIKISPACES_EDITING = "WikiSpaces-editing"
    WILDMETRIX = "WildMetrix"
    WINAMAX = "Winamax"
    WINAMP_REMOTE = "Winamp Remote"
    WINDOWS_AZURE = "windows-azure"
    WINDOWS_PUSH_NOTIFICATION = "Windows Push Notification"
    WINMX = "WinMX"
    WINNY = "Winny"
    WINS = "WINS"
    WIREDRIVE = "Wiredrive"
    WIXI = "Wixi"
    WLCCP = "WLCCP"
    WOLFENSTEIN = "Wolfenstein"
    WOOFILES = "Woofiles"
    WOOME = "WooMe"
    WORDFAST = "Wordfast"
    WORLD_OF_WARCRAFT = "World of Warcraft"
    WRITEBOARD = "Writeboard"
    WUALA = "Wuala"
    X_FONT_SERVER = "X Font Server"
    X_400 = "X.400"
    X1_MOBILE = "X1 Mobile"
    X11_PROTOCOL = "X11 Protocol"
    XBOX_LIVE = "Xbox Live"
    XDMCP = "xdmcp"
    XDRIVE = "Xdrive"
    XFIRE = "Xfire"
    XING = "XING"
    SIRIUS_XM_RADIO = "Sirius XM Radio"
    XOBNI = "Xobni"
    XUNLEI = "Xunlei"
    XUNLEI_KANKAN = "Xunlei Kankan"
    XWARE_XTRM = "Xware-xTRM"
    YAHOO_BLOG_POSTING = "Yahoo Blog-posting"
    YAHOOBOX = "YahooBox"
    YAHOO_CALENDAR = "Yahoo Calendar"
    YAHOO_DOUGA = "Yahoo Douga"
    YAHOO_FINANCE_POSTING = "Yahoo Finance-posting"
    YAHOO_MESSENGER = "Yahoo Messenger"
    YAHOO_MESSENGER_BASE = "Yahoo Messenger-base"
    YAHOO_MESSENGER_WEBCAM = "Yahoo Messenger-webcam"
    YAHOO_MESSENGER_VOICE = "Yahoo Messenger-voice"
    YAHOO_MESSENGER_FILE_TRANSFER = "Yahoo Messenger-file transfer"
    YAHOO_MAIL = "Yahoo Mail"
    YAHOO_NOTEPAD = "Yahoo Notepad"
    YAHOO_TOOLBAR = "Yahoo Toolbar"
    YAHOO_WEBMESSENGER = "Yahoo Webmessenger"
    YAMMER = "Yammer"
    YANDEX_DISK = "Yandex-disk"
    YANDEX_MAIL = "Yandex Mail"
    YANTRA = "Yantra"
    YIK_YAK = "Yik Yak"
    YOICS = "Yoics"
    YOOMBA = "Yoomba"
    YOONO = "Yoono"
    YOSEMITE_BACKUP = "Yosemite Backup"
    YOUKU = "Youku"
    YOUKU_UPLOADING = "Youku-uploading"
    YOUKU_BASE = "Youku-base"
    YOUR_FREEDOM = "Your Freedom"
    YOURFILEHOST = "Yourfilehost"
    YOURMINIS = "YourMinis"
    YOUSEEMORE = "YouSeeMore"
    YOUSENDIT = "YouSendIt"
    YOUSENDIT_BASE = "YouSendIt-base"
    YOUSENDIT_UPLOADING = "YouSendIt Uploading"
    YOUTUBE = "YouTube"
    YOUTUBE_POSTING = "YouTube-posting"
    YOUTUBE_UPLOADING = "YouTube-uploading"
    YOUTUBE_SAFETY_MODE = "YouTube-safety-mode"
    YOUTUBE_BASE = "YouTube-base"
    YPSERV = "ypserv"
    YUGMA = "Yugma"
    YUM = "yum"
    YUUGUU = "Yuuguu"
    YY_VOICE = "YY Voice"
    YY_VOICE_FILE_TRANSFER = "YY Voice-file transfer"
    YY_VOICE_GAMES = "YY Voice-games"
    YY_VOICE_BASE = "YY Voice-base"
    ZABBIX = "Zabbix"
    ZAMZAR = "ZAMZAR"
    ZANGO = "Zango"
    ZAS_COMMUNICATOR = "ZAS Communicator"
    ZBIGZ = "Zbigz"
    ZELUNE = "Zelune"
    ZENBE = "Zenbe"
    ZENDESK = "Zendesk"
    ZENMATE = "ZenMate"
    ZIMBRA = "Zimbra"
    ZMAAP = "Zmaap"
    ZOHO_CRM = "Zoho CRM"
    ZOHO_DB = "Zoho DB"
    ZOHO_CHAT = "Zoho Chat"
    ZOHO_MAIL = "Zoho Mail"
    ZOHO_MEETING = "Zoho Meeting"
    ZOHO_NOTEBOOK = "Zoho Notebook"
    ZOHO_PEOPLE = "Zoho People"
    ZOHO_PLANNER = "Zoho Planner"
    ZOHO_SHARE = "Zoho Share"
    ZOHO_SHEET = "Zoho Sheet"
    ZOHO_SHOW = "Zoho Show"
    ZOHO_WIKI = "Zoho Wiki"
    ZOHO_WRITER = "Zoho Writer"
    ZOOM = "Zoom"
    ZPL = "ZPL"
    ZUMODRIVE = "ZumoDrive"
    ZWIKI = "Zwiki"
    ZYNGA_GAMES = "Zynga Games"
    TRACEROUTE = "Traceroute"
    DROIDVPN = "DroidVPN"
    NDMP_PROTOCOL = "NDMP Protocol"
    DLMS = "Dlms"
    ICCP = "Iccp"
    SIEMENS_S7_BASE = "Siemens-s7-base"
    SIEMENS_S7_READ = "Siemens-s7-read"
    SIEMENS_S7_STOP = "Siemens-s7-stop"
    SIEMENS_S7_START = "Siemens-s7-start"
    SIEMENS_S7_SETUP_COMMUNICATION = "Siemens-s7-setup-communication"
    SIEMENS_S7_CHECK_PASSWORD_SET = "Siemens-s7-check-password-set"
    SNAPMIRROR = "Snapmirror"
    NIM = "Nim"
    SOCKS = "Socks"
    POP3 = "Pop3"
    TRADESTATION = "Tradestation"
    PORTMAP = "Portmap"
    STARCRAFT_II = "StarCraft II"
    MEMCACHED = "Memcached"
    OPENVPN = "OpenVPN"
    FASTTRACK = "Fasttrack"
    THECIRCLE = "Thecircle"
    LITTLE_FIGHTER_2 = "Little Fighter 2"
    KASPERSKY_LAB_UPDATE = "Kaspersky Lab-update"
    ROCKWELL_FACTORYTALK = "Rockwell-factorytalk"
    MS_DTC = "Ms-dtc"
    IBM_CONNECT_DIRECT = "Ibm-connect-direct"
    GOOGLE_VOICE_ACTIONS = "Google Voice Actions"
    IMAP_PROTOCOL = "Imap Protocol"
    LINKEDIN_INTRO = "Linkedin-intro"
    SYBASE = "Sybase"
    TIVOLI_STORAGE_MANAGER = "Tivoli-storage-manager"
    LOTUS_SAMETIME_UNYTE = "Lotus Sametime Unyte"
    NETBACKUP = "Netbackup"
    CONNECTED_BACKUP = "Connected Backup"
    GROUPWISE = "Groupwise"
    MS_KMS = "Ms-kms"
    H_323_PROTOCOL = "H.323 Protocol"
    H_225 = "H.225"
    MS_ISA_FW_CLIENT = "Ms-isa-fw-client"
    GOOD_DIRECT_CONNECT = "Good Direct Connect"
    HP_ILO = "Hp-ilo"
    ORACLE_IPM = "Oracle-ipm"
    MSNSHELL = "Msnshell"
    MQTT = "Mqtt"
    GKRELLM = "Gkrellm"
    TIVOLI_NETWORK_MONITORING = "Tivoli-network-monitoring"
    INTERSYSTEMS_CACHE = "Intersystems-cache"
    SCCP_PROTOCOL = "Sccp Protocol"
    MILLENIUM_ILS = "Millenium-ils"
    DNP3_BASE = "dnp3-base"
    DNP3_PROTOCOL___WRITE = "DNP3 Protocol - write"
    DNP3_PROTOCOL___READ = "DNP3 Protocol - read"
    DNP3_PROTOCOL___OPERATE = "DNP3 Protocol - operate"
    DNP3_PROTOCOL___DIRECT_OPERATE = "DNP3 Protocol - direct operate"
    HITACHI_SPC = "Hitachi-spc"
    PALOALTO_USERID_AGENT = "Paloalto-userid-agent"
    IFIX = "Ifix"
    OPENTEXT_ENTERPRISE_CONNECT = "Opentext-enterprise-connect"
    RTCM_SC104 = "Rtcm-sc104"
    MATRIKON_TUNNELLER = "Matrikon-tunneller"
    MS_FIREWALL_STORAGE = "Ms-firewall-storage"
    MICROSOFT_HYPER_V_CONNECT = "Microsoft Hyper-V-connect"
    FASP_PROTOCOL = "FASP Protocol"
    GITHUB_BASE = "github-base"
    GOTODEVICE = "Gotodevice"
    ABB_NETWORK_MANAGER = "Abb-network-manager"
    TEMENOS_T24 = "Temenos-t24"
    PHAROS = "Pharos"
    MGCP = "Mgcp"
    POWERBROKER = "Powerbroker"
    LSI_RAID_MANAGEMENT = "Lsi-raid-management"
    SYNERGY2 = "Synergy2"
    HOSPROXY = "Hosproxy"
    VEEAM = "Veeam"
    BRASS = "Brass"
    TRINOO = "Trinoo"
    UPNP_FORUM = "UPnP Forum"
    POCO = "Poco"
    SYMANTEC_SYST_CENTER = "Symantec-syst-center"
    MCAFEE = "Mcafee"
    BLUECOAT_ADN = "Bluecoat-adn"
    VERIZON_CLOUD = "Verizon Cloud"
    TESLA = "Tesla"
    TRACK_IT = "Track-it"
    FCIP = "FCIP"
    WAREZ = "Warez"
    SYSORB = "SysOrb"
    ISCSI = "Iscsi"
    ORACLE_ESSBASE = "Oracle-essbase"
    GTP_BASE = "Gtp-base"
    GTPV0 = "Gtpv0"
    GTP_PRIME = "Gtp-prime"
    AVID_ISIS = "Avid-isis"
    PEERENABLER = "Peerenabler"
    SUBVERSION_UPLOAD = "Subversion-upload"
    SUBVERSION_BASE = "subversion-base"
    TIME = "Time"
    NETMEETING = "Netmeeting"
    LDAP_PROTOCOL = "Ldap Protocol"
    NIMSH = "Nimsh"
    MIMACS = "Mimacs"
    MINACS_VERINT_RECORDING = "Minacs-verint-recording"
    SWIFTMQ = "Swiftmq"
    TIMBUKTU = "Timbuktu"
    KERIO_VPN = "Kerio VPN"
    PCOIP = "Pcoip"
    EPMD = "Epmd"
    ADOBE_CREATIVE_CLOUD_BASE = "adobe-creative-cloud-base"
    ADOBE_CREATIVE_CLOUD_FILE_TRANSFER = "Adobe Creative Cloud-file transfer"
    ALFRESCO = "Alfresco"
    APPCELERATOR = "Appcelerator"
    APPGURU = "Appguru"
    APPLE_SIRI = "Apple Siri"
    APPLE_VPP = "Apple-vpp"
    BAMBOO_CLOUD = "Bamboo Cloud"
    SILO = "Silo"
    AUTODESK360_BASE = "autodesk360-base"
    AUTODESK360_UPLOAD = "AutoDesk360-upload"
    BACKBLAZE = "BackBlaze"
    BITBUCKET_BASE = "bitbucket-base"
    BITBUCKET_UPLOAD = "Bitbucket-upload"
    BOXNET_CONSUMER_ACCESS = "Boxnet-consumer-access"
    BOXNET_ENTERPRISE_ACCESS = "Boxnet-enterprise-access"
    BROWSEC = "Browsec"
    CLOUD9 = "Cloud9"
    CLOUDSIGMA = "CloudSigma"
    DOTVPN = "DotVPN"
    DUOSECURITY = "Duosecurity"
    E_SIGNLIVE = "e-SignLive"
    ENGINEYARD = "Engineyard"
    EVERNOTE_UPLOAD = "Evernote-upload"
    FACEBOOK_VOICE = "Facebook-voice"
    FACEBOOK_VIDEO_UPLOAD = "Facebook-video-upload"
    FINCH = "Finch"
    GITHUB_UPLOAD = "GitHub-upload"
    GLOBALMEET_FILE_TRANSFER = "Globalmeet-file-transfer"
    GOOGLE_APP_ENGINE_UPLOAD = "Google App Engine-upload"
    HOMEPIPE = "Homepipe"
    IM_PLUS_MOBILE = "IM Plus-mobile"
    IMO_IM = "Imo IM"
    INFORMATICA_CLOUD = "Informatica-cloud"
    INTACCT = "Intacct"
    LANTERN = "Lantern"
    LOGENTRIES = "Logentries"
    LOTUSLIVE_MEETING = "LotusLive-meeting"
    MABBER = "Mabber"
    MEGA_BASE = "mega-base"
    MELDIUM = "Meldium"
    MS_EXCHANGE_ADMIN_CENTER = "Ms-exchange-admin-center"
    MS_ONENOTE = "Ms-onenote"
    ONEPAGECRM = "Onepagecrm"
    PALOALTO_UPDATES = "Paloalto-updates"
    PALOALTO_WILDFIRE_CLOUD = "Paloalto-wildfire-cloud"
    PAN_DB_CLOUD = "Pan-db-cloud"
    PUSHBULLET = "Pushbullet"
    RALLY_SOFTWARE = "Rally-software"
    SALESFORCE_DESK = "Salesforce-desk"
    SAMANAGE = "Samanage"
    SECUREMEETING = "SecureMeeting"
    SEND_ANYWHERE = "Send Anywhere"
    SENDGRID = "SendGrid"
    SENDTHISFILE_UPLOAD = "SendThisFile-upload"
    SEVEN_EMAIL = "Seven-email"
    SFAX = "Sfax"
    SHAREVAULT_BASE = "sharevault-base"
    SHAREVAULT_FILE_TRANSFER = "Sharevault-file-transfer"
    SKYTAP = "Skytap"
    SLACK_BASE = "slack-base"
    SLACK_FILE_TRANSFER = "Slack-file-transfer"
    SPANNING = "Spanning"
    SRVDIR = "srvdir"
    STARTMAIL = "Startmail"
    SUMOLOGIC = "Sumologic"
    TEAMUP_CALENDAR_UPLOAD = "Teamup Calendar-upload"
    TELEX = "Telex"
    TENABLE_SECURITY_CENTER = "Tenable-security-center"
    TOTOEXPRESS = "Totoexpress"
    TOUCHDOWN = "Touchdown"
    TRENDMICRO_SAFESYNC = "Trendmicro-safesync"
    TRUESHARE = "Trueshare"
    UNYTE = "Unyte"
    WEBROOT_SECUREANYWHERE_ANTIVIRUS = "Webroot SecureAnywhere AntiVirus"
    WICKR = "Wickr"
    XERO = "Xero"
    TIGERTEXT = "Tigertext"
    BIME = "BIME"
    EVENTBRITE = "Eventbrite"
    EVERNOTE_BASE = "evernote-base"
    FRESHBOOKS = "Freshbooks"
    FRIENDVOX = "Friendvox"
    GLOBALMEET_BASE = "Globalmeet-base"
    LAST_FM = "Last FM"
    MAILCHIMP = "Mailchimp"
    OFFICE_LIVE = "Office-live"
    OKTA = "okta"
    PHPROXY = "Phproxy"
    PROOFHQ = "ProofHQ"
    SEEQPOD = "Seeqpod"
    SKY_PLAYER = "Sky-player"
    TAKU_FILE_BIN = "Taku-file-bin"
    TECHINLINE_REMOTE_DESKTOP = "Techinline Remote Desktop"
    TRANSFERBIGFILES_COM = "TransferBigFiles.com"
    WEBDAV_PROTOCOL = "WebDAV Protocol"
    WEB_CRAWLER = "Web-crawler"
    STEGANOS_INTERNET_ANONYM_VPN = "Steganos Internet Anonym VPN"
    SOPHOS_LIVE_PROTECTION = "Sophos-live protection"
    FIREFOX_HELLO = "Firefox-hello"
    FREEDOME = "Freedome"
    SIMPLIFY = "Simplify"
    HOVRS = "Hovrs"
    PALRINGO_RICH_MESSAGING = "Palringo Rich Messaging"
    FLEXNET_PUBLISHER = "Flexnet-publisher"
    POCKETCLOUD_REMOTE_DESKTOP = "PocketCloud-Remote Desktop"
    AMAZON_WORKSPACE = "Amazon-workspace"
    TESLA_CAR_APP = "Tesla Car App"
    CRYPTOCAT = "Cryptocat"
    THREEMA = "Threema"
    JABBER_MESSENGER = "Jabber Messenger"
    INFRONT = "Infront"
    ADOBE_DOCUMENT_CLOUD = "Adobe Document Cloud"
    AGILOFT = "Agiloft"
    BOLDCHAT_LOGMEIN = "Boldchat-logmein"
    CALLIDUS = "Callidus"
    CLICKTOOLS = "Clicktools"
    CLOUDSHARE = "Cloudshare"
    DATTO_BACKUPIFY = "datto-backupify"
    GOOGLE_WAVE = "Google-wave"
    HIPCHAT_FILE_SHARING = "HipChat-file sharing"
    HUDDLE_BASE = "Huddle-base"
    HUDDLE_UPLOAD = "Huddle-upload"
    INSTAGRAM_BASE = "Instagram-base"
    INSTAGRAM_UPLOAD = "Instagram-upload"
    UCLOUD = "ucloud"
    MEDIUM_IM = "Medium-im"
    ODRIVE = "odrive"
    SAP_JAM_UPLOAD = "SAP-jam-upload"
    STOCKTWITS_BASE = "Stocktwits-base"
    STOCKTWITS_POSTING = "Stocktwits-posting"
    SUCCESSFACTORS = "Successfactors"
    TRELLO_BASE = "Trello-base"
    TRELLO_UPLOAD = "Trello-upload"
    ADOBE_CONNECT_MEETING_SCREEN_SHARING = "Adobe Connect-meeting-screen sharing"
    ZELLO = "Zello"
    VIDSOFT = "Vidsoft"
    NAVER_LINE = "Naver-line"
    MS_LYNC_CONTENT_SHARING = "Ms-lync-content-sharing"
    MCAFEE_EPOLICY_ORCHESTRATOR = "McAfee ePolicy Orchestrator"
    ITWIN = "Itwin"
    TENABLE_NESSUS = "Tenable-nessus"
    SABA_CENTRA = "Saba Centra"
    REALTUNNEL = "Realtunnel"
    SITEMINDER = "Siteminder"
    ALPHA_ANYWHERE = "Alpha-anywhere"
    SALTSTACK = "Saltstack"
    LOGLOGIC = "Loglogic"
    TSUNAMI_UDP = "Tsunami-UDP"
    MULT_IP = "Mult-ip"
    REGNUM_ONLINE = "Regnum Online"
    SECURE_ACCESS_SYNC = "Secure-access-sync"
    WEBALO = "Webalo"
    MUNIN = "Munin"
    SYNOLOGY_DSM = "Synology-dsm"
    RSA_SECURITY_ANALYTICS = "Rsa-security-analytics"
    TRENDMICRO_EARTHAGENT = "Trendmicro-earthagent"
    LANDESK_INVENTORY = "Landesk-inventory"
    SIP_PROTOCOL = "SIP Protocol"
    SIP_TRUNK = "Sip-trunk"
    SIPVIAHEADER_NAT = "Sipviaheader-nat"
    RINGCENTRAL = "Ringcentral"
    OASYS_SCADA = "Oasys-scada"
    R_SERVICES = "R-services"
    RWHO = "Rwho"
    LPD = "Lpd"
    GTUNNEL = "Gtunnel"
    NCP_PROTOCOL = "Ncp Protocol"
    GOBOOGY = "Goboogy"
    LLMNR_PROTOCOL = "LLMNR Protocol"
    UUCP_PROTOCOL = "Uucp Protocol"
    NETSUPPORT_MANAGER = "NetSupport Manager"
    KLOGIN = "Klogin"
    POSTGRESQL_PROTOCOL = "PostgreSQL Protocol"
    AMAZON_REDSHIFT = "Amazon-redshift"
    POCKET_CONTROLLER = "Pocket Controller"
    SOTI_MOBICONTROL = "Soti-mobicontrol"
    LRS_OUTPUT_MANAGEMENT = "Lrs-output-management"
    TXP = "Txp"
    RTSP_PROTOCOL = "Rtsp Protocol"
    MCAFEE_ENDPOINT_ENCRYPTION = "Mcafee-endpoint-encryption"
    MS_DPM = "Ms-dpm"
    WINDOWS_REMOTE_MANAGEMENT___WINRM = "Windows Remote Management - WinRm"
    SIP2_FOR_ILS = "Sip2-for-ils"
    IMAGENOW = "Imagenow"
    IPP = "Ipp"
    NEONET = "Neonet"
    MSDP = "Msdp"
    FOXT_BOKS_SERVERCONTROL = "Foxt-boks-servercontrol"
    FACTSET = "Factset"
    BMC_BCO_BEST1 = "Bmc-bco-best1"
    TFTP_PROTOCOL = "TFTP Protocol"
    GOPHER_PROTOCOL = "Gopher Protocol"
    T3 = "T3"
    ORACLE_ALP = "Oracle-alp"
    PNA = "Pna"
    ESTOS_PROCALL = "Estos-procall"
    INFOR_ERP_LN = "Infor-erp-ln"
    MAXDB = "Maxdb"
    HEROIX_LONGITUDE = "Heroix-longitude"
    MICROS = "Micros"
    FLEXNET_INSTALLANYWHERE = "Flexnet-installanywhere"
    SIEMENS_FACTORYLINK = "Siemens-factorylink"
    SOLVEQUOTES = "Solvequotes"
    JUNIPER_NSM = "Juniper-nsm"
    RIVERBED_STEELHEAD_MOBILE = "Riverbed-steelhead-mobile"
    FINGER_PROTOCOL = "Finger Protocol"
    _CH_BASE = "2ch-base"
    RSS_CNN_NEWS = "RSS CNN News"
    DAUM_TVPOT = "Daum-tvpot"
    DNF = "DNF"
    ETELOS_CRM = "Etelos-crm"
    F_SECURE_UPDATER = "F-secure-updater"
    FETCH_IO = "Fetch.io"
    FILE_HOST = "File-host"
    FIX = "Fix"
    GIFBOOM = "GifBoom"
    GOOGLE_UPDATE = "Google-update"
    GROOVE_MUSIC = "Groove Music"
    IMEEM = "Imeem"
    IMHAHA = "Imhaha"
    IM2_INSTANT_MESSENGER = "IM2 Instant Messenger"
    ITV = "ITV"
    JNET = "Jnet"
    JOTSPOT_EDITING = "Jotspot-editing"
    LIFECAM = "Lifecam"
    LOGITECH_WEBCAM = "Logitech-webcam"
    MEDIAWIKI_EDITING = "Mediawiki-editing"
    MEEBO_REPEATER = "Meebo Repeater"
    MEETRO = "Meetro"
    MOTLEYFOOL_POSTING = "Motleyfool-posting"
    MSN_MONEY = "msn Money"
    MSN_TOOLBAR = "Msn-toolbar"
    MSN_WEB_MESSENGER = "MSN Web Messenger"
    NATEON_MAIL = "NateOn-mail"
    NAVER_BLOG_POSTING = "Naver Blog-posting"
    NETEASE_WEBDISK_BASE = "netease-webdisk-base"
    NETEASE_WEBDISK_UPLOAD = "Netease Webdisk-upload"
    NETEASE_WEBDISK_DOWNLOAD = "Netease Webdisk-download"
    NFL_STREAMING = "Nfl-streaming"
    OUTBLAZE_MAIL = "Outblaze-mail"
    PBWIKI_EDITING = "Pbwiki-editing"
    PEERGUARDIAN = "Peerguardian"
    PHPWIKI_EDITING = "Phpwiki-editing"
    PINGFU_IRIS = "PingFu Iris"
    PLUGOO_WIDGET = "Plugoo-widget"
    POPCORN_TIME = "Popcorn Time"
    QUANTUM_EDGE_TMS = "Quantum-edge-tms"
    RADIUSIM = "Radiusim"
    SCEP_PROTOCOL = "SCEP Protocol"
    SEND_TO_PHONE = "Send-to-phone"
    SHAREBASE_TO = "Sharebase.to"
    SINA_WEB_UC = "Sina Web UC"
    SOCIALTEXT = "Socialtext"
    SOLARWINDS_SAM = "Solarwinds-sam"
    SOLARWINDS_NPM = "Solarwinds-npm"
    SOLARWINDS_BASE = "Solarwinds-base"
    STARZ = "Starz"
    SWAPPERNET = "Swappernet"
    THINKFREE = "Thinkfree"
    TISTORY = "Tistory"
    TITANIZE = "Titanize"
    TORCH_MUSIC = "Torch Music"
    TORCH_GAMES = "Torch Games"
    TURBOUPLOAD_COM = "Turboupload.com"
    TVTONIC = "Tvtonic"
    TWIG = "Twig"
    ULTRAHOOK = "UltraHook"
    UNION_PROCEDURE_CALL = "Union-procedure-call"
    UPLOADING_COM = "Uploading.com"
    UPLOADMIRRORS = "Uploadmirrors"
    WEBAIM = "Webaim"
    WEBCONNECT = "Webconnect"
    WEBHARD = "Webhard"
    WINK = "Wink"
    ZETTAHOST_TV_UPLOAD = "ZettaHost.tv-upload"
    OFFICE365_CONSUMER_ACCESS = "Office365-consumer-access"
    OFFICE365_ENTERPRISE_ACCESS = "Office365-enterprise-access"
    PALOALTO_APERTURE = "Paloalto-aperture"
    NEOKAST = "Neokast"
    VEOH_VIDEO_UPLOAD = "Veoh-video upload"
    FEIDIAN = "Feidian"
    QVOD_PLAYER = "Qvod Player"
    IQIYI = "iQIYI"
    FREEPP = "FreePP"
    UNREAL = "Unreal"
    ZETTAHOST_BASE = "Zettahost-base"
    TELEVISION_BROADCASTS_LIMITED = "Television Broadcasts Limited"
    LIVENEWSCHAT = "Livenewschat"
    JEPPTECH_UPDATES = "Jepptech-updates"
    PALO_ALTO_TRAPS = "Palo Alto Traps"
    EXACQVISION = "Exacqvision"
    SPAMFIGHTER = "SPAMfighter"
    MS_GROOVE = "Ms-groove"
    SENTILLION = "Sentillion"
    MEABOX = "Meabox"
    PLEX = "Plex"
    GOODSYNC = "GoodSync"
    ADOBE_ECHOSIGN = "Adobe-echosign"
    AFTER_SCHOOL = "After School"
    ATMAIL = "atmail"
    ATT_OFFICE_AT_HAND = "Att-office-at-hand"
    BASE_CRM = "Base-crm"
    BUZZSAW = "Buzzsaw"
    CLEARSLIDE = "ClearSlide"
    CONVO_CHAT = "Convo-chat"
    CONVO_BASE = "Convo-base"
    CONVO_UPLOAD = "Convo-upload"
    COTAP = "Cotap"
    DOCHUB_BASE = "DocHub-base"
    DOCHUB_UPLOAD = "DocHub-upload"
    INSYNC = "Insync"
    DRUVA_PHOENIX = "Druva-phoenix"
    EFOLDER_BACKUP = "eFolder Backup"
    ESPN_PLAYER_STREAMING = "ESPN Player-streaming"
    FACEBOOK_MESSENGER_UPLOAD = "Facebook Messenger-upload"
    FACEBOOK_ROOMS = "Facebook-rooms"
    FLASH = "Flash"
    GOAGENT = "Goagent"
    GOODDATA = "GoodData"
    GOOGLE_CALENDAR_POSTING = "Google-calendar-posting"
    GOOGLE_CLASSROOM = "Google-classroom"
    GOOGLE_CLOUD_STORAGE_BASE = "google-cloud-storage-base"
    GOOGLE_CLOUD_STORAGE_UPLOAD = "Google Cloud Storage-upload"
    HANGOUTS_CHAT = "Hangouts-chat"
    GOOGLE_PHOTOS = "Google Photos"
    HAMI_CLOUD = "Hami Cloud"
    DBANK = "DBank"
    HUBSPOT = "HubSpot"
    IGLOO = "Igloo"
    IMGUR_UPLOAD = "imgur-upload"
    IMGUR_BASE = "imgur-base"
    INSIGHTLY_CRM = "Insightly CRM"
    INTUIT_QUICKBASE = "Intuit-quickbase"
    JDI_BACKUP = "JDI Backup"
    JOBVITE = "Jobvite"
    KASPERSKY = "Kaspersky"
    LG_UPLUS_NETURO = "Lg-uplus-neturo"
    MAPI_OVER_HTTP = "Mapi-over-http"
    MAYTECH_QUATRIX_FILE_SHARING = "Maytech quatrix-file sharing"
    MAYTECH_BASE = "maytech-base"
    MAYTECH_QUATRIX_UPLOAD = "Maytech quatrix-upload"
    MAYTECH_QUATRIX_DOWNLOAD = "Maytech quatrix-download"
    MEERKAT = "Meerkat"
    MENDELEY_BASE = "mendeley-base"
    MENDELEY_UPLOAD = "Mendeley-upload"
    META4 = "Meta4"
    MINUS = "Minus"
    MOXTRA = "Moxtra"
    MS_ONEDRIVE_SHARE = "Ms-onedrive-share"
    MICROSOFT_ONEDRIVE_UPLOAD = "Microsoft OneDrive-upload"
    MS_ONEDRIVE_BASE = "ms-onedrive-base"
    MS_ONEDRIVE_DOWNLOADING = "Ms-onedrive-downloading"
    NETOP_REMOTE_CONTROL___ONDEMAND = "Netop Remote Control - OnDemand"
    NETSPOKE = "Netspoke"
    NOKIA_HERE_MAPS = "Nokia-here-maps"
    NOMADESK = "NomaDesk"
    ONELOGIN = "OneLogin"
    ORACLE_CRM_ONDEMAND = "Oracle-crm-ondemand"
    ORACLE_ELOQUA = "Oracle-eloqua"
    ORSISO = "Orsiso"
    PAGERDUTY = "Pagerduty"
    PALOALTO_AUTOFOCUS = "Paloalto-autofocus"
    PANDA_UPDATE = "Panda-update"
    PERISCOPE = "Periscope"
    PINGONE = "PingOne"
    PINTEREST_BASE = "pinterest-base"
    PINTEREST_POSTING = "Pinterest-posting"
    PINTEREST_MESSAGING = "Pinterest-messaging"
    PITCHENGINE = "PitchEngine"
    PIVOTALTRACKER_BASE = "pivotaltracker-base"
    PIVOTAL_TRACKER_UPLOAD = "Pivotal Tracker-upload"
    PIVOTAL_TRACKER_DOWNLOAD = "Pivotal Tracker-download"
    PROOFHUB_BASE = "Proofhub-base"
    PROOFHUB_FILE_TRANSFER = "ProofHub-file transfer"
    PUBNUB = "PubNub"
    PUFFIN = "Puffin"
    EASY_INSTALL = "Easy-Install"
    QLIKVIEW = "Qlikview"
    REDDIT_BASE = "reddit-base"
    REDDIT_POSTING = "Reddit-posting"
    REZGO = "Rezgo"
    RIGHTSCALE = "RightScale"
    RUCKUS = "Ruckus"
    SAASU = "Saasu"
    SAP_JAM_BASE = "sap-jam-base"
    SCREENCAST_BASE = "screencast-base"
    SCREENCAST_COM_UPLOAD = "Screencast.com-upload"
    SECRET = "Secret"
    SECURESERVER_MAIL = "Secureserver-mail"
    SENDTHISFILE_BASE = "sendthisfile-base"
    SERVICE_NOW = "Service-now"
    SHAVLIK_NETCHK = "Shavlik-netchk"
    SHODAN = "Shodan"
    SHOEBOX = "Shoebox"
    SMARTSHEET_BASE = "Smartsheet-base"
    SMARTSHEET_UPLOAD = "Smartsheet-upload"
    SOLIDFILES = "Solidfiles"
    SOS_ONLINE_BACKUP = "SOS Online Backup"
    SOURCEFORGE_FILE_TRANSFER = "Sourceforge-file-transfer"
    STORIFY_POSTING = "Storify-posting"
    STORIFY_BASE = "storify-base"
    STREETCHAT = "Streetchat"
    SURVEYMONKEY = "Surveymonkey"
    SWAY = "Sway"
    TEAMUP_CALENDAR_BASE = "teamup-calendar-base"
    TEAMVIEWER_WEB = "Teamviewer-web"
    TELEGRAM = "Telegram"
    TORCH_BROWSER_BASE = "Torch-browser-base"
    TRENDMICRO = "Trendmicro"
    TUBES = "Tubes"
    TURBOSHARE = "Turboshare"
    UBISOFT_UPLAY = "Ubisoft Uplay"
    UC_YUN_BASE = "uc-yun-base"
    UC_YUN_UPLOADING = "Uc-yun-uploading"
    UC_YUN_DOWNLOADING = "Uc-yun-downloading"
    USERMIN = "Usermin"
    USERPLANE_WEBMESSENGER = "UserPlane WebMessenger"
    VAGRANT = "Vagrant"
    VEVO = "Vevo"
    VIRUSTOTAL_BASE = "virustotal-base"
    VIRUSTOTAL_WEB_UPLOADING = "virustotal-web-uploading"
    VIRUSTOTAL_API_UPLOADING = "Virustotal-api-uploading"
    WATCH_ABC = "Watch-abc"
    WEATHER_DESKTOP = "Weather-desktop"
    WEB_DE_MAIL = "Web-de-mail"
    WHISPER = "Whisper"
    WINDOWS_AZURE_UPLOADING = "Windows-azure-uploading"
    WUFOO = "Wufoo"
    WWE_NETWORK = "Wwe-network"
    YAHOO_ANALYTICS = "Yahoo Analytics"
    YODLEE = "Yodlee"
    YUNPAN360_FILE_TRANSFER = "Yunpan360-file-transfer"
    YUNPAN360_BASE = "Yunpan360-base"
    HANGOUTS_AUDIO_VIDEO = "Hangouts-audio-video"
    SLACK_CALL = "Slack-call"
    NINTENDO_WFC = "Nintendo-wfc"
    KHAN_ACADEMY = "Khan-academy"
    STRONGVPN = "StrongVPN"
    MAGICJACK = "Magicjack"
    JUMP_DESKTOP = "Jump Desktop"
    SIMPLEHELP = "SimpleHelp"
    OPERA_MINI2 = "Opera-mini"
    LANDESK_BASE = "landesk-base"
    BEATS_MUSIC = "Beats Music"
    DROPCAM = "Dropcam"
    TWITCH_TV_VIDEO_PLAY = "Twitch.tv-video play"
    CLUBBOX = "Clubbox"
    TEAMDRIVE_BASE = "teamdrive-base"
    TEAMDRIVE_UPLOAD = "TeamDrive-upload"
    ORIDUS_NETTOUCH = "Oridus-nettouch"
    QUICKOFFICE = "Quickoffice"
    AEROFS = "AeroFS"
    GMX = "GMX"
    SILENT_CIRCLE = "Silent Circle"
    _X8 = "8x8"
    GOOGLE_HANGOUTS_BASE = "Google-hangouts-base"
    HIPCHAT_BASE = "hipchat-base"
    GOOGLE_BASE = "Google-base"
    CHATON = "ChatON"
    KACE = "Kace"
    YUNPAN = "Yunpan"
    ANYDESK = "AnyDesk"
    LIVE_MEETING = "Live-meeting"
    MS_EXCHANGE_MRS = "Ms-exchange-mrs"
    ANYTERM = "Anyterm"
    LIMELIGHT_NETWORKS = "Limelight Networks"
    CITRIX_XENMOBILE = "Citrix-xenmobile"
    WINDOWS_AZURE_BASE = "Windows-azure-base"
    MYMARKETS = "Mymarkets"
    TINDER = "Tinder"
    APACHE_SOLR = "Apache-solr"
    PLURALSIGHT = "Pluralsight"
    SOURCEFORGE_BASE = "Sourceforge-base"
    HEXATECH_VPN = "Hexatech VPN"
    MERAKI_CLOUD_CONTROLLER = "Meraki Cloud Controller"
    ASK_FM = "Ask.fm"
    POPO = "POPO"
    SLING = "Sling"
    OPENMEETINGS = "OpenMeetings"
    MISSLEE_MESSENGER = "MissLee Messenger"
    VPN_MASTER = "VPN Master"
    DOUBLE_TAKE_AVAILABILITY = "Double-take-availability"
    HOLA = "Hola"
    WEIYUN_FILE_TRANSFER = "Weiyun-file transfer"
    STORIX = "Storix"
    PROXYLOCAL = "ProxyLocal"
    SYMANTEC_ENDPOINT_PROTECTION_MANAGER = "Symantec Endpoint Protection Manager"
    ICECAST = "Icecast"
    MERCURIAL_UPLOADING = "Mercurial-uploading"
    MERCURIAL_BASE = "Mercurial-base"
    SCREENCONNECT = "ScreenConnect"
    TRENDMICRO_OFFICESCAN = "Trendmicro-officescan"
    REUTERS_DATA_SERVICE = "Reuters-data-service"
    IGEL = "Igel"
    ISO_8583 = "Iso-8583"
    KERBEROS_PROTOCOL = "Kerberos Protocol"
    GHOSTSURF = "Ghostsurf"
    OPENEDGE = "OpenEdge"
    UNIFLOW = "Uniflow"
    MCAFEE_MOVE_AV = "Mcafee-move-av"
    SWYX_CDS = "Swyx-cds"
    INFOPRINT = "Infoprint"
    POSTSCRIPT_PDL = "Postscript-pdl"
    TOSHIBA_TEC_PCL = "Toshiba-tec-pcl"
    LEXMARK_HBN3 = "Lexmark-hbn3"
    WINDOWS_AZURE_SERVICE_UPDATES = "Windows-azure-service-updates"
    D2D_DATA_TRANSFER = "D2d-data-transfer"
    VMWARE_VSPHERE_WEB_CLIENT = "Vmware-vsphere-web-client"
    NETS = "Nets"
    ORACLE_BI = "Oracle-bi"
    COUCHBASE = "Couchbase"
    DEMONSAW = "Demonsaw"
    DYNATRACE_APP_MONITORING = "Dynatrace-app-monitoring"
    ENHANCED_FILE_TRANSFER = "Enhanced-file-transfer"
    G_HO = "G.ho"
    GLIDE___VIDEO_TEXTING = "Glide - Video Texting"
    GROUPMAX = "Groupmax"
    H_245 = "H.245"
    IBM_SOLIDDB = "Ibm-soliddb"
    ICAP = "Icap"
    INFOREACH = "Inforeach"
    INNOVATIVE = "Innovative"
    JENKINS = "Jenkins"
    JMUX = "Jmux"
    LAWSON_M3 = "Lawson-m3"
    LIFESIZE = "Lifesize"
    LOCALTUNNEL = "localtunnel"
    MEETING_MAKER = "Meeting-maker"
    MEGASHARES_COM = "Megashares.com"
    MOVE_NETWORKS = "Move-networks"
    MS_FRS = "Ms-frs"
    MS_IIS = "Ms-iis"
    MS_WMI_PROTOCOL = "MS-WMI Protocol"
    NEPTUNE = "Neptune"
    NET_TCP_PROTOCOL = "Net.TCP Protocol"
    NETWARE_REMOTE_CONSOLE = "Netware-remote-console"
    OFFICEHARD = "Officehard"
    OPC = "Opc"
    ORACLE_FORMS = "Oracle-forms"
    ORION_RHAPSODY = "Orion Rhapsody"
    OVO_LOGGER = "Ovo-logger"
    PERFECT_DARK = "Perfect Dark"
    POKERSTARS = "PokerStars"
    PRINT_OVER_MS_SMB = "Print-over-ms-smb"
    RELP = "Relp"
    RMI_IIOP = "Rmi-iiop"
    SAXOPRESS = "Saxopress"
    SCOTTY = "Scotty"
    SEAMLESS_PHENOM = "Seamless-phenom"
    SHAREBOX = "Sharebox"
    SILVERLAKE_AXIS_SIBS = "Silverlake-axis-sibs"
    SIMPLE_CHAT = "Simple Chat"
    SOURCEFIRE_FIREAMP = "Sourcefire-fireamp"
    SPECTOR360 = "Spector360"
    TEAMCENTER = "Teamcenter"
    TOTODISK = "Totodisk"
    TVUPLAYER = "TVUPlayer"
    WARCRAFT_III = "Warcraft III"
    WEBOT = "Webot"
    WEIYUN_BASE = "weiyun-base"
    WINBOX = "Winbox"
    NETVAULT_BACKUP = "Netvault-backup"
    FCC_SPEED_TEST = "Fcc-speed-test"
    FILES_WIRE = "Files Wire"
    GNUTELLA_PROTOCOL = "Gnutella Protocol"
    JXTA = "Jxta"
    KONTIKI = "Kontiki"
    LANSCHOOL = "Lanschool"
    LEAGUE_OF_LEGENDS = "League Of Legends"
    MOUNT_PROTOCOL = "MOUNT Protocol"
    MS_EXCHANGE = "Ms-exchange"
    MSRPC_EXCHANGE_SERVICES = "MSRPC Exchange Services"
    NET2PHONE = "Net2phone"
    NOMACHINE = "NoMachine"
    QQ_RDP = "Qq-rdp"
    RTP_AUDIO = "Rtp-audio"
    RTP_VIDEO = "Rtp-video"
    SECURITY_KISS = "Security-kiss"
    SHARE_P2P = "Share-p2p"
    SOCIALTV = "Socialtv"
    SOURCE_ENGINE = "Source-engine"
    SYNOLOGY_CLOUDSTATION = "Synology-cloudstation"
    VIDYO = "Vidyo"
    VYPRVPN = "Vyprvpn"
    LWAPP = "Lwapp"
    NETBIOS_DG = "Netbios-dg"
    VQP = "Vqp"
    GE_EGD = "Ge-egd"
    HSRP = "Hsrp"
    WCCP = "Wccp"
    INFOBLOX_GRID = "Infoblox-grid"
    GTPV1_C = "Gtpv1-c"
    GTPV2_C = "Gtpv2-c"
    GTP_U = "Gtp-u"
    QUAKE3_PROTOCOL = "Quake3 Protocol"
    UAUDP = "Uaudp"
    NETVMG_TRACEROUTE = "Netvmg-traceroute"
    PROFINET = "Profinet"
    TEREDO = "Teredo"
    TSP = "Tsp"
    RADIUS_DYNAMIC_AUTHORIZATION = "Radius-dynamic-authorization"
    NORTON_AV_BROADCAST = "Norton-av-broadcast"
    HIPCHAT_AUDIO_VIDEO = "Hipchat-audio-video"
    MERU_L3_AP_COMM = "Meru-l3-ap-comm"
    MOBILITY_XE = "Mobility-xe"
    SIPCLI = "SipCLI"
    RIP_PROTOCOL = "Rip Protocol"
    RIPNG_PROTOCOL = "RIPng Protocol"
    RPING = "Rping"
    VERIZON_NETWORK_EXTENDER = "Verizon-network-extender"
    FORTIGUARD_WEBFILTER = "Fortiguard-webfilter"
    SECURID = "SecurID"
    MOSH = "Mosh"
    RMCP = "Rmcp"
    IBM_RMC = "Ibm-rmc"
    BEAMPRO_TELEPRESENCE = "Beampro-telepresence"
    QUIC_PROTOCOL = "Quic Protocol"
    IBM_MOBILE_CONNECT = "Ibm-mobile-connect"
    MERU_L3_AP_DISCOVERY = "Meru-l3-ap-discovery"
    MERU_L3_AP_DATA = "Meru-l3-ap-data"
    RIVERBED_STEELHEAD_SAAS = "Riverbed-steelhead-saas"
    FREENET = "Freenet"
    GENERIC_P2P = "Generic-p2p"
    H_248 = "H.248"
    ICHAT = "iChat"
    ITALKBB_CHINESE_TV = "Italkbb-chinese-tv"
    MEGACHAT = "MegaChat"
    MPEG_ORG = "MPEG.org"
    NETFLOW = "NetFlow"
    RSTATD = "Rstatd"
    RTP_BASE = "Rtp-base"
    RUSERS = "Rusers"
    SIP_APPLICATION = "Sip-application"
    SIP_MESSAGING = "SIP-messaging"
    SKYPE_PROBE = "Skype-probe"
    SUBSPACE = "Subspace"
    WECHAT_AUDIO_VIDEO_CHAT = "WeChat-audio video chat"
    WHATSAPP_VOICE = "Whatsapp-voice"
    ACCELLION = "Accellion"
    AUTODESK360 = "Autodesk360"
    CONVO = "Convo"
    DOCHUB = "DocHub"
    GLOBALMEET = "Globalmeet"
    HANGOUTS = "Hangouts"
    GTP = "Gtp"
    THE_HUDDLE = "The Huddle"
    IMGUR = "imgur"
    MAYTECH_QUATRIX = "Maytech quatrix"
    MERCURIAL = "Mercurial"
    MICROSOFT_ONEDRIVE = "Microsoft OneDrive"
    NETEASE_WEBDISK = "Netease Webdisk"
    MICROSOFT_OUTLOOK_WEB = "Microsoft Outlook-web"
    OVATION = "Ovation"
    PIVOTAL_TRACKER = "Pivotal Tracker"
    PROOFHUB = "Proofhub"
    PROPALMS = "Propalms"
    REDDIT = "Reddit"
    RELIABLE_DATA = "Reliable-data"
    SAP_JAM = "SAP-jam"
    SCREENCAST_COM = "Screencast.com"
    SENDTHISFILE = "SendThisFile"
    SHAREVAULT = "Sharevault"
    SIEMENS_S7 = "Siemens-s7"
    SLACK = "Slack"
    SMARTSHEET = "Smartsheet"
    SOLARWINDS = "Solarwinds"
    SPEEDVPN = "Speedvpn"
    STOCKTWITS = "Stocktwits"
    STORIFY = "Storify"
    SUBVERSION = "Subversion"
    TEAMDRIVE = "TeamDrive"
    TEAMUP_CALENDAR = "Teamup Calendar"
    TORCH_BROWSER = "Torch-browser"
    TRELLO = "Trello"
    UC_YUN = "UC Yun"
    WEIYUN = "Weiyun"
    WORKDAY = "Workday"
    _YUNPAN = "360Yunpan"
    ZETTAHOST_TV = "ZettaHost.tv"
    _SEVENOFFICE = "24sevenoffice"
    _SHIFTS = "7shifts"
    ACCELO = "Accelo"
    ACME_PROTOCOL = "Acme-Protocol"
    ACRONIS_CLOUD_BACKUP = "Acronis-Cloud-Backup"
    ACTIVE_DIRECTORY_BASE = "Active-Directory-Base"
    ADOBE_MEETING_UPLOADING = "Adobe-Meeting-Uploading"
    AEROSPIKE = "Aerospike"
    AIRTABLE = "Airtable"
    AIRTABLE_BASE = "Airtable-Base"
    AIRTABLE_DOWNLOADING = "Airtable-Downloading"
    AIRTABLE_EDITING = "Airtable-Editing"
    AIRTABLE_POSTING = "Airtable-Posting"
    AIRTABLE_SHARING = "Airtable-Sharing"
    AIRTABLE_UPLOADING = "Airtable-Uploading"
    AIRWATCH = "Airwatch"
    AMAZON_ALEXA = "Amazon-Alexa"
    AMAZON_CHIME = "Amazon-Chime"
    AMAZON_ECHO = "Amazon-Echo"
    AMAZON_MUSIC = "Amazon-Music"
    AMAZON_MUSIC_BASE = "Amazon-Music-Base"
    AMAZON_MUSIC_STREAMING = "Amazon-Music-Streaming"
    APPDYNAMICS = "Appdynamics"
    APPOGEE = "Appogee"
    APPOINTY = "Appointy"
    APPTIVO = "Apptivo"
    ASSEMBLA = "Assembla"
    ASSEMBLA_BASE = "Assembla-Base"
    ASSEMBLA_UPLOADING = "Assembla-Uploading"
    AVOCENT_VSP = "Avocent-Vsp"
    BACNET_BASE = "Bacnet-Base"
    BACNET_ACK_ALARM = "Bacnet-Ack-Alarm"
    BACNET_ADD_LIST_ELEMENT = "Bacnet-Add-List-Element"
    BACNET_ATOMIC_READ_FILE = "Bacnet-Atomic-Read-File"
    BACNET_ATOMIC_WRITE_FILE = "Bacnet-Atomic-Write-File"
    BACNET_AUTHENTICATE = "Bacnet-Authenticate"
    BACNET_CONFIRMED_COV_NOTIFY = "Bacnet-Confirmed-Cov-Notify"
    BACNET_CONFIRMED_EVENT_NOTIFY = "Bacnet-Confirmed-Event-Notify"
    BACNET_CONFIRMED_PRIVATE_XFER = "Bacnet-Confirmed-Private-Xfer"
    BACNET_CONFIRMED_TEXT_MESSAGE = "Bacnet-Confirmed-Text-Message"
    BACNET_CREATE_OBJECT = "Bacnet-Create-Object"
    BACNET_DELETE_OBJECT = "Bacnet-Delete-Object"
    BACNET_DEVICE_COMM_CONTROL = "Bacnet-Device-Comm-Control"
    BACNET_GET_ALARM_SUMMARY = "Bacnet-Get-Alarm-Summary"
    BACNET_GET_ENROLLMENT_SUMMARY = "Bacnet-Get-Enrollment-Summary"
    BACNET_GET_EVENT_INFORMATION = "Bacnet-Get-Event-Information"
    BACNET_LIFE_SAFETY_OPERATION = "Bacnet-Life-Safety-Operation"
    BACNET_READ_PROP_CONDITIONAL = "Bacnet-Read-Prop-Conditional"
    BACNET_READ_PROP_MULTIPLE = "Bacnet-Read-Prop-Multiple"
    BACNET_READ_PROPERTY = "Bacnet-Read-Property"
    BACNET_READ_RANGE = "Bacnet-Read-Range"
    BACNET_REINITIALIZE_DEVICE = "Bacnet-Reinitialize-Device"
    BACNET_REMOVE_LIST_ELEMENT = "Bacnet-Remove-List-Element"
    BACNET_REQUEST_KEY = "Bacnet-Request-Key"
    BACNET_SUBSCRIBE_COV = "Bacnet-Subscribe-Cov"
    BACNET_SUBSCRIBE_COV_PROPERTY = "Bacnet-Subscribe-Cov-Property"
    BACNET_VT_CLOSE = "Bacnet-Vt-Close"
    BACNET_VT_DATA = "Bacnet-Vt-Data"
    BACNET_VT_OPEN = "Bacnet-Vt-Open"
    BACNET_WRITE_PROP_MULTIPLE = "Bacnet-Write-Prop-Multiple"
    BACNET_WRITE_PROPERTY = "Bacnet-Write-Property"
    BASECAMP = "Basecamp"
    BBC_STREAMING = "Bbc-Streaming"
    BENCHMARK = "Benchmark"
    BING_MAPS = "Bing-Maps"
    BITRIX24 = "Bitrix24"
    BKPER = "Bkper"
    BOOMERANG = "Boomerang"
    BOXNET_DOWNLOADING = "Boxnet-Downloading"
    BOXNET_SHARING = "Boxnet-Sharing"
    C9_TRADER = "C9-Trader"
    CAKEHR = "Cakehr"
    CANVAS = "Canvas"
    CAPSULE = "Capsule"
    CARESTREAM = "Carestream"
    CATAPULT = "Catapult"
    CC_LINK = "Cc-Link"
    CELLCRYPT = "Cellcrypt"
    CELOXIS = "Celoxis"
    CENTRELI = "Centreli"
    CERNER = "Cerner"
    CERTIFY = "Certify"
    CISCO_SPARK = "Cisco-Spark"
    CISCO_SPARK_BASE = "Cisco-Spark-Base"
    CISCO_SPARK_AUDIO_VIDEO = "Cisco-Spark-Audio-Video"
    CISCO_SPARK_FILE_TRANSFER = "Cisco-Spark-File-Transfer"
    CISCO_SXP = "Cisco-Sxp"
    CITRIX_PROVISIONING = "Citrix-Provisioning"
    CLASSIN = "Classin"
    CLOSE_IO = "Close.io"
    CLOUDAPP = "Cloudapp"
    CLOUDAPP_BASE = "Cloudapp-Base"
    CLOUDAPP_UPLOADING = "Cloudapp-Uploading"
    CLOUDCHERRY = "Cloudcherry"
    CLOUDFORGE = "Cloudforge"
    CLOUDFORGE_BASE = "Cloudforge-Base"
    CLOUDFORGE_UPLOADING = "Cloudforge-Uploading"
    CLOUDINARY = "Cloudinary"
    CLOUDINARY_BASE = "Cloudinary-Base"
    CLOUDINARY_UPLOADING = "Cloudinary-Uploading"
    CLOUDUP = "Cloudup"
    COINBASE = "Coinbase"
    COINHAVE = "Coinhave"
    COINHIVE = "Coinhive"
    COINIMP = "Coinimp"
    COINNEBULA = "Coinnebula"
    CONCUR_BASE = "Concur-Base"
    CONCUR_DOWNLOADING = "Concur-Downloading"
    CONCUR_EDITING = "Concur-Editing"
    CONCUR_UPLOADING = "Concur-Uploading"
    CONFLUENCE_BASE = "Confluence-Base"
    CONFLUENCE_DOWNLOADING = "Confluence-Downloading"
    CONFLUENCE_EDITING = "Confluence-Editing"
    CONFLUENCE_POSTING = "Confluence-Posting"
    CONFLUENCE_SHARING = "Confluence-Sharing"
    CONFLUENCE_UPLOADING = "Confluence-Uploading"
    COVERITY = "Coverity"
    CRUCIBLE = "Crucible"
    CRYPTO_LOOT = "Crypto-Loot"
    CYLANCE = "Cylance"
    CYPH = "Cyph"
    CYPH_BASE = "Cyph-Base"
    CYPH_AUDIO_VIDEO = "Cyph-Audio-Video"
    CYPH_FILE_TRANSFER = "Cyph-File-Transfer"
    DAPULSE = "Dapulse"
    DATADOG = "Datadog"
    DEEPMINER = "Deepminer"
    DIALPAD = "Dialpad"
    DIAMETER_BASE = "Diameter-Base"
    DINGTALK = "Dingtalk"
    DIRECTV = "Directv"
    DISCORD = "Discord"
    DNP3_ABORT_FILE = "Dnp3-Abort-File"
    DNP3_ASSIGN_CLASS = "Dnp3-Assign-Class"
    DNP3_AUTHENTICATE_FILE = "Dnp3-Authenticate-File"
    DNP3_CLOSE_FILE = "Dnp3-Close-File"
    DNP3_COLD_RESTART = "Dnp3-Cold-Restart"
    DNP3_CONFIRM = "Dnp3-Confirm"
    DNP3_DELAY_MEASUREMENT = "Dnp3-Delay-Measurement"
    DNP3_DELETE_FILE = "Dnp3-Delete-File"
    DNP3_DIRECT_OPERATE_NO_RESP = "Dnp3-Direct-Operate-No-Resp"
    DNP3_DISABLE_UNSOLICITED = "Dnp3-Disable-Unsolicited"
    DNP3_ENABLE_UNSOLICITED = "Dnp3-Enable-Unsolicited"
    DNP3_FREEZE = "Dnp3-Freeze"
    DNP3_FREEZE_AT_TIME = "Dnp3-Freeze-At-Time"
    DNP3_FREEZE_AT_TIME_NO_RESP = "Dnp3-Freeze-At-Time-No-Resp"
    DNP3_FREEZE_CLEAR = "Dnp3-Freeze-Clear"
    DNP3_FREEZE_CLEAR_NO_RESP = "Dnp3-Freeze-Clear-No-Resp"
    DNP3_FREEZE_NO_RESP = "Dnp3-Freeze-No-Resp"
    DNP3_GET_FILE_INFORMATION = "Dnp3-Get-File-Information"
    DNP3_INITIALIZE_APPLICATION = "Dnp3-Initialize-Application"
    DNP3_INITIALIZE_DATA = "Dnp3-Initialize-Data"
    DNP3_OPEN_FILE = "Dnp3-Open-File"
    DNP3_RECORD_CURRENT_TIME = "Dnp3-Record-Current-Time"
    DNP3_SAVE_CONFIGURATION = "Dnp3-Save-Configuration"
    DNP3_SELECT = "Dnp3-Select"
    DNP3_START_APPLICATION = "Dnp3-Start-Application"
    DNP3_STOP_APPLICATION = "Dnp3-Stop-Application"
    DNP3_WARM_RESTART = "Dnp3-Warm-Restart"
    DOBIMIGRATE = "Dobimigrate"
    DOCUSIGN_BASE = "Docusign-Base"
    DOCUSIGN_CONSUMER_ACCESS = "Docusign-Consumer-Access"
    DOCUSIGN_DOWNLOADING = "Docusign-Downloading"
    DOCUSIGN_EDITING = "Docusign-Editing"
    DOCUSIGN_ENTERPRISE_ACCESS = "Docusign-Enterprise-Access"
    DOCUSIGN_UPLOADING = "Docusign-Uploading"
    DRAW_IO = "Draw.io"
    DRAW_IO_BASE = "Draw.io-Base"
    DRAW_IO_CLOUD = "Draw.io-Cloud"
    DROPBOX_BASE = "Dropbox-Base"
    DROPBOX_DOWNLOADING = "Dropbox-Downloading"
    DROPBOX_EDITING = "Dropbox-Editing"
    DROPBOX_LANSYNC_DISCOVERY = "Dropbox-Lansync-Discovery"
    DROPBOX_PAPER = "Dropbox-Paper"
    DROPBOX_POSTING = "Dropbox-Posting"
    DROPBOX_SHARING = "Dropbox-Sharing"
    DROPBOX_UPLOADING = "Dropbox-Uploading"
    ECOUNT_ERP = "Ecount-Erp"
    ED137 = "Ed137"
    ED137_BASE = "Ed137-Base"
    ED137_PTT_OFF_SQU_OFF = "Ed137-Ptt-Off-Squ-Off"
    ED137_PTT_OFF_SQU_ON = "Ed137-Ptt-Off-Squ-On"
    ED137_PTT_ON_SQU_OFF = "Ed137-Ptt-On-Squ-Off"
    ED137_PTT_ON_SQU_ON = "Ed137-Ptt-On-Squ-On"
    EGNYTE_BASE = "Egnyte-Base"
    EGNYTE_DOWNLOADING = "Egnyte-Downloading"
    EGNYTE_EDITING = "Egnyte-Editing"
    EGNYTE_POSTING = "Egnyte-Posting"
    EGNYTE_SHARING = "Egnyte-Sharing"
    EGNYTE_UPLOADING = "Egnyte-Uploading"
    EPIC = "Epic"
    ERICOM_CONNECT = "Ericom-Connect"
    ERPAG = "Erpag"
    EVERCONTACT = "Evercontact"
    EVERNOTE_DOWNLOADING = "Evernote-Downloading"
    EVERNOTE_EDITING = "Evernote-Editing"
    EVERNOTE_POSTING = "Evernote-Posting"
    EVERNOTE_SHARING = "Evernote-Sharing"
    FANUC_FOCAS = "Fanuc-Focas"
    FIDELITY_ACTIVE_TRADER_PRO = "Fidelity-Active-Trader-Pro"
    FILESTACK = "Filestack"
    FILESTACK_BASE = "Filestack-Base"
    FILESTACK_DOWNLOADING = "Filestack-Downloading"
    FILESTACK_UPLOADING = "Filestack-Uploading"
    FIREFOX_SEND = "Firefox-Send"
    FLOCK = "Flock"
    FLUENTSTREAM = "Fluentstream"
    FORTNITE = "Fortnite"
    FRESHDESK = "Freshdesk"
    FRESHSALES = "Freshsales"
    FRONT = "Front"
    FUNCTIONFOX = "Functionfox"
    G_HO_ST = "G.ho.st"
    GAT = "Gat"
    GB2PP = "Gb2pp"
    GB2PP_BASE = "Gb2pp-Base"
    GB2PP_PTT_OFF = "Gb2pp-Ptt-Off"
    GB2PP_PTT_ON = "Gb2pp-Ptt-On"
    GB2PP_TONE_OFF = "Gb2pp-Tone-Off"
    GB2PP_TONE_ON = "Gb2pp-Tone-On"
    GE_HISTORIAN = "Ge-Historian"
    GENESYS_INTERACTION_SERVER = "Genesys-Interaction-Server"
    GITHUB_DOWNLOADING = "Github-Downloading"
    GITHUB_EDITING = "Github-Editing"
    GITHUB_POSTING = "Github-Posting"
    GITLAB = "Gitlab"
    GITLAB_BASE = "Gitlab-Base"
    GITLAB_UPLOADING = "Gitlab-Uploading"
    GLASSDOOR = "Glassdoor"
    GLASSDOOR_BASE = "Glassdoor-Base"
    GLASSDOOR_DOWNLOADING = "Glassdoor-Downloading"
    GLASSDOOR_EDITING = "Glassdoor-Editing"
    GLASSDOOR_POSTING = "Glassdoor-Posting"
    GLASSDOOR_UPLOADING = "Glassdoor-Uploading"
    GLIP = "Glip"
    GLOBUS = "Globus"
    GMAIL_DOWNLOADING = "Gmail-Downloading"
    GMAIL_POSTING = "Gmail-Posting"
    GMAIL_UPLOADING = "Gmail-Uploading"
    GOOGLE_CLOUD_STORAGE_DOWNLOAD = "Google-Cloud-Storage-Download"
    GOOGLE_CLOUD_STORAGE_EDITING = "Google-Cloud-Storage-Editing"
    GOOGLE_CLOUD_STORAGE_SHARING = "Google-Cloud-Storage-Sharing"
    GOOGLE_DOCS_DOWNLOADING = "Google-Docs-Downloading"
    GOOGLE_DOCS_POSTING = "Google-Docs-Posting"
    GOOGLE_DOCS_SHARING = "Google-Docs-Sharing"
    GOOGLE_DUO = "Google-Duo"
    GOOGLE_EXPEDITIONS = "Google-Expeditions"
    GOOGLE_MEET = "Google-Meet"
    GOOGLE_SPACES = "Google-Spaces"
    GOOGLE_SPACES_BASE = "Google-Spaces-Base"
    GOOGLE_SPACES_POSTING = "Google-Spaces-Posting"
    GOTOWEBINAR = "Gotowebinar"
    GOTOWEBINAR_BASE = "Gotowebinar-Base"
    GOTOWEBINAR_DOWNLOADING = "Gotowebinar-Downloading"
    GOTOWEBINAR_UPLOADING = "Gotowebinar-Uploading"
    GOVERLAN = "Goverlan"
    GQUEUES = "Gqueues"
    GRAMMARLY = "Grammarly"
    HARVEST = "Harvest"
    HELPRACE = "Helprace"
    HELPSCOUT = "Helpscout"
    HIPCHAT_DOWNLOADING = "Hipchat-Downloading"
    HIPCHAT_EDITING = "Hipchat-Editing"
    HIPCHAT_POSTING = "Hipchat-Posting"
    HIPCHAT_SHARING = "Hipchat-Sharing"
    HIPCHAT_UPLOADING = "Hipchat-Uploading"
    HOOTSUITE_BASE = "Hootsuite-Base"
    HOOTSUITE_POSTING = "Hootsuite-Posting"
    HOOTSUITE_SHARING = "Hootsuite-Sharing"
    HOOTSUITE_UPLOADING = "Hootsuite-Uploading"
    HP_RGS = "Hp-Rgs"
    HPE_BSA = "Hpe-Bsa"
    IBM_CONTROL_CENTER = "Ibm-Control-Center"
    ICCP_BASE = "Iccp-Base"
    ICCP_DEFINE_NAMED_TYPE = "Iccp-Define-Named-Type"
    ICCP_DEFINE_NAMED_VARIABLE = "Iccp-Define-Named-Variable"
    ICCP_DEFINE_NAMED_VARIABLE_LIST = "Iccp-Define-Named-Variable-List"
    ICCP_DEFINE_SCATTERED_ACCESS = "Iccp-Define-Scattered-Access"
    ICCP_DEFINE_SEMAPHORE = "Iccp-Define-Semaphore"
    ICCP_DELETE_NAMED_TYPE = "Iccp-Delete-Named-Type"
    ICCP_DELETE_NAMED_VARIABLE_LIST = "Iccp-Delete-Named-Variable-List"
    ICCP_DELETE_SEMAPHORE = "Iccp-Delete-Semaphore"
    ICCP_DELETE_VARIABLE_ACCESS = "Iccp-Delete-Variable-Access"
    ICCP_DOWNLOAD_SEGMENT = "Iccp-Download-Segment"
    ICCP_GET_NAME_LIST = "Iccp-Get-Name-List"
    ICCP_GET_NAMED_TYPE_ATTR = "Iccp-Get-Named-Type-Attr"
    ICCP_GET_NAMED_VAR_LIST_ATTR = "Iccp-Get-Named-Var-List-Attr"
    ICCP_GET_SCATTERED_ACCESS_ATTR = "Iccp-Get-Scattered-Access-Attr"
    ICCP_GET_VARIABLE_ACCESS_ATTR = "Iccp-Get-Variable-Access-Attr"
    ICCP_IDENTITY = "Iccp-Identity"
    ICCP_INITIATE_DOWNLOAD_SEQ = "Iccp-Initiate-Download-Seq"
    ICCP_INITIATE_UPLOAD_SEQ = "Iccp-Initiate-Upload-Seq"
    ICCP_INPUT = "Iccp-Input"
    ICCP_OUTPUT = "Iccp-Output"
    ICCP_READ = "Iccp-Read"
    ICCP_RELINQUISH_CONTROL = "Iccp-Relinquish-Control"
    ICCP_RENAME = "Iccp-Rename"
    ICCP_REPORT_POOL_SEM_STATUS = "Iccp-Report-Pool-Sem-Status"
    ICCP_REPORT_SEM_ENTRY_STATUS = "Iccp-Report-Sem-Entry-Status"
    ICCP_REPORT_SEMAPHORE_STATUS = "Iccp-Report-Semaphore-Status"
    ICCP_STATUS = "Iccp-Status"
    ICCP_TAKE_CONTROL = "Iccp-Take-Control"
    ICCP_TERMINATE_DOWNLOAD_SEQ = "Iccp-Terminate-Download-Seq"
    ICCP_WRITE = "Iccp-Write"
    IEEE_PTP = "Ieee-Ptp"
    INFUSIONSOFT = "Infusionsoft"
    INTERCALL = "Intercall"
    INTERVALS = "Intervals"
    IPFS = "Ipfs"
    IPVANISH = "Ipvanish"
    ISILON_SYNCIQ = "Isilon-Synciq"
    IVEF = "Ivef"
    IXLOAD = "Ixload"
    JAMF = "Jamf"
    JFROG_ARTIFACTORY = "Jfrog-Artifactory"
    JIRA_BASE = "Jira-Base"
    JIRA_DOWNLOADING = "Jira-Downloading"
    JIRA_EDITING = "Jira-Editing"
    JIRA_POSTING = "Jira-Posting"
    JIRA_UPLOADING = "Jira-Uploading"
    JSECOIN = "Jsecoin"
    JUMPSHARE = "Jumpshare"
    JUMPSHARE_BASE = "Jumpshare-Base"
    JUMPSHARE_UPLOADING = "Jumpshare-Uploading"
    KAFKA = "Kafka"
    KAYAKO = "Kayako"
    KINTONE = "Kintone"
    KISSFLOW = "Kissflow"
    KIXIE = "Kixie"
    KUGOU = "Kugou"
    LEANKIT = "Leankit"
    LEARNOSITY = "Learnosity"
    LINKEDIN_EDITING = "Linkedin-Editing"
    LUCIDCHART = "Lucidchart"
    LUCIDPRESS = "Lucidpress"
    LUCIDPRESS_BASE = "Lucidpress-Base"
    LUCIDPRESS_EDITING = "Lucidpress-Editing"
    MALWAREBYTES = "Malwarebytes"
    MASTODON = "Mastodon"
    MATLAB = "Matlab"
    MINDMEISTER = "Mindmeister"
    MINERALT = "Mineralt"
    MS_DC_REPLICATION = "Ms-Dc-Replication"
    MS_DELVE = "Ms-Delve"
    MS_DIRECTORY_SERVICE_SETUP = "Ms-Directory-Service-Setup"
    MS_DS_SMB_BASE = "Ms-Ds-Smb-Base"
    MS_DS_SMBV1 = "Ms-Ds-Smbv1"
    MS_DS_SMBV2 = "Ms-Ds-Smbv2"
    MS_DS_SMBV3 = "Ms-Ds-Smbv3"
    MS_EVENT_LOG = "Ms-Event-Log"
    MS_LOCAL_SECURITY_MANAGEMENT = "Ms-Local-Security-Management"
    MS_LOCAL_USER_MANAGEMENT = "Ms-Local-User-Management"
    MS_POWERBI = "Ms-Powerbi"
    MS_REMOTE_REGISTRY = "Ms-Remote-Registry"
    MS_STORE = "Ms-Store"
    MS_TEAMS = "Ms-Teams"
    MS_TEAMS_DOWNLOADING = "Ms-Teams-Downloading"
    MS_TEAMS_EDITING = "Ms-Teams-Editing"
    MS_TEAMS_POSTING = "Ms-Teams-Posting"
    MS_TEAMS_SHARING = "Ms-Teams-Sharing"
    MS_TEAMS_UPLOADING = "Ms-Teams-Uploading"
    MS_WORKSTATION_SERVICE = "Ms-Workstation-Service"
    MSRPC_BASE = "Msrpc-Base"
    MSSQL_DB_BASE = "Mssql-Db-Base"
    MSSQL_DB_ENCRYPTED = "Mssql-Db-Encrypted"
    MSSQL_DB_UNENCRYPTED = "Mssql-Db-Unencrypted"
    MTCONNECT = "Mtconnect"
    MUSICAL_LY = "Musical.ly"
    NASUNI = "Nasuni"
    NAVER_STREAMING = "Naver-Streaming"
    NEWTON_MAIL = "Newton-Mail"
    NICE = "Nice"
    NOW_TV = "Now-TV"
    NOW_TV_BASE = "Now-TV-Base"
    NOW_TV_STREAMING = "Now-TV-Streaming"
    OPC_DA = "Opc-Da"
    OPERA_VPN = "Opera-Vpn"
    OWNCLOUD_BASE = "Owncloud-Base"
    OWNCLOUD_DELETING = "Owncloud-Deleting"
    OWNCLOUD_DOWNLOADING = "Owncloud-Downloading"
    OWNCLOUD_EDITING = "Owncloud-Editing"
    OWNCLOUD_POSTING = "Owncloud-Posting"
    OWNCLOUD_SHARING = "Owncloud-Sharing"
    OWNCLOUD_UPLOADING = "Owncloud-Uploading"
    PALOALTO_DIRECTORY_SYNC = "Paloalto-Directory-Sync"
    PALOALTO_GP_MFA_NOTIFICATION = "Paloalto-Gp-Mfa-Notification"
    PALOALTO_LOGGING_SERVICE = "Paloalto-Logging-Service"
    PALOALTO_SHARED_SERVICES = "Paloalto-Shared-Services"
    PANORAMA_INTERCONNECT = "Panorama-Interconnect"
    PAPERCUT = "Papercut"
    PLAYSTATION_NOW = "Playstation-Now"
    PNRP = "Pnrp"
    PREZI_BASE = "Prezi-Base"
    PREZI_POSTING = "Prezi-Posting"
    PREZI_UPLOADING = "Prezi-Uploading"
    PRODUCTPLAN = "Productplan"
    PROTONMAIL = "Protonmail"
    QLIKSENSE_CLOUD = "Qliksense-Cloud"
    QLIKSENSE_CLOUD_BASE = "Qliksense-Cloud-Base"
    QLIKSENSE_CLOUD_DOWNLOADING = "Qliksense-Cloud-Downloading"
    QLIKSENSE_CLOUD_EDITING = "Qliksense-Cloud-Editing"
    QLIKSENSE_CLOUD_SHARING = "Qliksense-Cloud-Sharing"
    QLIKSENSE_CLOUD_UPLOADING = "Qliksense-Cloud-Uploading"
    QUIP = "Quip"
    QUIP_BASE = "Quip-Base"
    QUIP_DOWNLOADING = "Quip-Downloading"
    QUIP_EDITING = "Quip-Editing"
    QUIP_POSTING = "Quip-Posting"
    QUIP_SHARING = "Quip-Sharing"
    QUIP_UPLOADING = "Quip-Uploading"
    QUORA_BASE = "Quora-Base"
    QUORA_POSTING = "Quora-Posting"
    QUORA_UPLOADING = "Quora-Uploading"
    R_GOOSE = "R-Goose"
    RABBIT = "Rabbit"
    RALLY_SOFTWARE_BASE = "Rally-Software-Base"
    RALLY_SOFTWARE_DOWNLOADING = "Rally-Software-Downloading"
    RALLY_SOFTWARE_EDITING = "Rally-Software-Editing"
    RALLY_SOFTWARE_SHARING = "Rally-Software-Sharing"
    RALLY_SOFTWARE_UPLOADING = "Rally-Software-Uploading"
    REALTIMEBOARD = "Realtimeboard"
    RIVERBED_RIOS = "Riverbed-Rios"
    ROBLOX = "Roblox"
    ROC = "Roc"
    RSA_SECURID_MFA_API = "Rsa-Securid-Mfa-Api"
    SALESFORCE_DOWNLOADING = "Salesforce-Downloading"
    SALESFORCE_EDITING = "Salesforce-Editing"
    SALESFORCE_POSTING = "Salesforce-Posting"
    SALESFORCE_SHARING = "Salesforce-Sharing"
    SALESFORCE_UPLOADING = "Salesforce-Uploading"
    SAMSUNG_TIZEN_PUSH = "Samsung-Tizen-Push"
    SAP_HANA = "Sap-Hana"
    SECS_GEM = "Secs-Gem"
    SECURE_DATA_SPACE = "Secure-Data-Space"
    SECURE_DATA_SPACE_BASE = "Secure-Data-Space-Base"
    SECURE_DATA_SPACE_DOWNLOADING = "Secure-Data-Space-Downloading"
    SECURE_DATA_SPACE_EDITING = "Secure-Data-Space-Editing"
    SECURE_DATA_SPACE_POSTING = "Secure-Data-Space-Posting"
    SECURE_DATA_SPACE_SHARING = "Secure-Data-Space-Sharing"
    SECURE_DATA_SPACE_UPLOADING = "Secure-Data-Space-Uploading"
    SEL_FAST_MESSAGING = "Sel-Fast-Messaging"
    SENTINELONE = "Sentinelone"
    SERIAL_OVER_LAN = "Serial-Over-Lan"
    SERVICE_NOW_BASE = "Service-Now-Base"
    SERVICE_NOW_DOWNLOADING = "Service-Now-Downloading"
    SERVICE_NOW_EDITING = "Service-Now-Editing"
    SERVICE_NOW_POSTING = "Service-Now-Posting"
    SERVICE_NOW_SHARING = "Service-Now-Sharing"
    SERVICE_NOW_UPLOADING = "Service-Now-Uploading"
    SHAREFILE_DOWNLOADING = "Sharefile-Downloading"
    SHAREFILE_EDITING = "Sharefile-Editing"
    SHAREPOINT_ONLINE_DOWNLOADING = "Sharepoint-Online-Downloading"
    SHAREPOINT_ONLINE_EDITING = "Sharepoint-Online-Editing"
    SHAREPOINT_ONLINE_SHARING = "Sharepoint-Online-Sharing"
    SHAREPOINT_ONLINE_UPLOADING = "Sharepoint-Online-Uploading"
    SHOWMAX = "Showmax"
    SHOWMAX_BASE = "Showmax-Base"
    SHOWMAX_STREAMING = "Showmax-Streaming"
    SHOWTIME = "Showtime"
    SIEMENS_S7_STATUS_CONTROLLER = "Siemens-S7-Status-Controller"
    SIGNAL = "Signal"
    SILVERPEAK_EDGECONNECT = "Silverpeak-Edgeconnect"
    SLACK_DOWNLOADING = "Slack-Downloading"
    SLACK_EDITING = "Slack-Editing"
    SLACK_SHARING = "Slack-Sharing"
    SLACK_UPLOADING = "Slack-Uploading"
    SMARTSHEET_DOWNLOADING = "Smartsheet-Downloading"
    SMARTSHEET_EDITING = "Smartsheet-Editing"
    SMARTSHEET_SHARING = "Smartsheet-Sharing"
    SMPP = "Smpp"
    SNARE_SERVER = "Snare-Server"
    SOLARWINDS_MSP_ANYWHERE = "Solarwinds-Msp-Anywhere"
    SONARQUBE = "Sonarqube"
    SOURCEFORGE_DOWNLOADING = "Sourceforge-Downloading"
    SOURCEFORGE_UPLOADING = "Sourceforge-Uploading"
    SPROUTSOCIAL = "Sproutsocial"
    SUITELINK = "Suitelink"
    SURVEYMONKEY_BASE = "Surveymonkey-Base"
    SURVEYMONKEY_DOWNLOADING = "Surveymonkey-Downloading"
    SURVEYMONKEY_EDITING = "Surveymonkey-Editing"
    SURVEYMONKEY_SHARING = "Surveymonkey-Sharing"
    SURVEYMONKEY_UPLOADING = "Surveymonkey-Uploading"
    SYMPHONY = "Symphony"
    SYNCPLICITY_BASE = "Syncplicity-Base"
    SYNCPLICITY_DOWNLOADING = "Syncplicity-Downloading"
    SYNCPLICITY_SHARING = "Syncplicity-Sharing"
    SYNCPLICITY_UPLOADING = "Syncplicity-Uploading"
    TABLEAU_BASE = "Tableau-Base"
    TABLEAU_DOWNLOADING = "Tableau-Downloading"
    TABLEAU_EDITING = "Tableau-Editing"
    TABLEAU_UPLOADING = "Tableau-Uploading"
    TAOBAO = "Taobao"
    TEAMSOUND = "Teamsound"
    TERADATA = "Teradata"
    TEXTNOW = "Textnow"
    TGX_REMOTE_DESKTOP = "Tgx-Remote-Desktop"
    THOUSANDEYES = "Thousandeyes"
    TIDAL = "Tidal"
    TRAPS_MANAGEMENT_SERVICE = "Traps-Management-Service"
    TRELLO_DOWNLOADING = "Trello-Downloading"
    TRELLO_EDITING = "Trello-Editing"
    TRESORIT = "Tresorit"
    TWITTER_EDITING = "Twitter-Editing"
    TWITTER_UPLOADING = "Twitter-Uploading"
    UNISYS_STEALTH = "Unisys-Stealth"
    UNKNOWN_P2P = "Unknown-P2p"
    VELPIC = "Velpic"
    VERTICA = "Vertica"
    VIBER_DOWNLOADING = "Viber-Downloading"
    VIBER_UPLOADING = "Viber-Uploading"
    VMWARE_UPDATE = "Vmware-Update"
    WATCHDOX_BASE = "Watchdox-Base"
    WATCHDOX_DOWNLOADING = "Watchdox-Downloading"
    WATCHDOX_EDITING = "Watchdox-Editing"
    WATCHDOX_SHARING = "Watchdox-Sharing"
    WATCHDOX_UPLOADING = "Watchdox-Uploading"
    WEBEX_DOWNLOADING = "Webex-Downloading"
    WEBEX_UPLOADING = "Webex-Uploading"
    WEBHR = "Webhr"
    WEBMINE = "Webmine"
    WEEKDONE = "Weekdone"
    WHATSAPP_WEB = "Whatsapp-Web"
    WHENIWORK = "Wheniwork"
    WINDOWS_DEFENDER_ATP = "Windows-Defender-Atp"
    WINDOWS_DEFENDER_ATP_BASE = "Windows-Defender-Atp-Base"
    WINDOWS_DEFENDER_ATP_ENDPOINT = "Windows-Defender-Atp-Endpoint"
    WINDOWS_DEFENDER_ATP_PORTAL = "Windows-Defender-Atp-Portal"
    WIRE = "Wire"
    WISESTAMP = "Wisestamp"
    WORKABLE = "Workable"
    WORKDAY_BASE = "Workday-Base"
    WORKDAY_DOWNLOADING = "Workday-Downloading"
    WORKDAY_EDITING = "Workday-Editing"
    WORKDAY_UPLOADING = "Workday-Uploading"
    WRIKE = "Wrike"
    XFINITY_TV = "Xfinity-Tv"
    YAHOO_MAIL_BASE = "Yahoo-Mail-Base"
    YAHOO_MAIL_DOWNLOADING = "Yahoo-Mail-Downloading"
    YAHOO_MAIL_POSTING = "Yahoo-Mail-Posting"
    YAHOO_MAIL_UPLOADING = "Yahoo-Mail-Uploading"
    YAMMER_BASE = "Yammer-Base"
    YAMMER_DOWNLOADING = "Yammer-Downloading"
    YAMMER_EDITING = "Yammer-Editing"
    YAMMER_SHARING = "Yammer-Sharing"
    YAMMER_UPLOADING = "Yammer-Uploading"
    YANDEX_MAPS = "Yandex-Maps"
    YELP = "Yelp"
    YELP_BASE = "Yelp-base"
    YELP_SHARING = "Yelp-sharing"
    YELP_POSTING = "Yelp-posting"
    YELP_EDITING = "Yelp-editing"
    YELP_UPLOADING = "Yelp-uploading"
    YOUTUBE_STREAMING = "Youtube-Streaming"
    YOUTUBE_TV = "Youtube-Tv"
    YOUTUBE_TV_STREAMING = "Youtube-Tv-Streaming"
    ZALO = "Zalo"
    ZALO_BASE = "Zalo-Base"
    ZALO_AUDIO_VIDEO = "Zalo-Audio-Video"
    ZENDESK_BASE = "Zendesk-Base"
    ZENDESK_DOWNLOADING = "Zendesk-Downloading"
    ZENDESK_EDITING = "Zendesk-Editing"
    ZENDESK_UPLOADING = "Zendesk-Uploading"
    ZENEFITS = "Zenefits"
    ZENEFITS_BASE = "Zenefits-Base"
    ZENEFITS_DOWNLOADING = "Zenefits-Downloading"
    ZENEFITS_EDITING = "Zenefits-Editing"
    ZENEFITS_UPLOADING = "Zenefits-Uploading"
    ZERTO_VIRTUAL_REPLICATION = "Zerto-Virtual-Replication"
    ZIPPYSHARE = "Zippyshare"
    ZOOM_BASE = "Zoom-Base"
    ZOOM_DOWNLOADING = "Zoom-Downloading"
    ZOOM_MEETING = "Zoom-Meeting"
    ZOOM_SHARING = "Zoom-Sharing"
    ZOOM_UPLOADING = "Zoom-Uploading"
